/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <stdbool.h>
/************ Begin %include sections from the grammar ************************/
#line 56 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"

#include "sqlInt.h"
#include "box/fk_constraint.h"

/*
** Disable all error recovery processing in the parser push-down
** automaton.
*/
#define YYNOERRORRECOVERY 1

/*
** Make yytestcase() the same as testcase()
*/
#define yytestcase(X) testcase(X)

/*
** Indicate that sqlParserFree() will never be called with a null
** pointer.
*/
#define YYPARSEFREENEVERNULL 1

/*
** Alternative datatype for the argument to the malloc() routine passed
** into sqlParserAlloc().  The default is size_t.
*/
#define YYMALLOCARGTYPE  u64

/*
 * Stop the parser if an error occurs. This macro adds an
 * additional check that allows the parser to be stopped if any
 * error was noticed.
 */
#define PARSER_ERROR_CHECK && ! pParse->is_aborted

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** Disable lookaside memory allocation for objects that might be
** shared across database connections.
*/
static void disableLookaside(Parse *pParse){
  pParse->disableLookaside++;
  pParse->db->lookaside.bDisable++;
}

#line 479 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"

  /**
   * For a compound SELECT statement, make sure
   * p->pPrior->pNext==p for all elements in the list. And make
   * sure list length does not exceed SQL_LIMIT_COMPOUND_SELECT.
   */
  static void parserDoubleLinkSelect(Parse *pParse, Select *p){
    if( p->pPrior ){
      Select *pNext = 0, *pLoop;
      int mxSelect, cnt = 0;
      for(pLoop=p; pLoop; pNext=pLoop, pLoop=pLoop->pPrior, cnt++){
        pLoop->pNext = pNext;
        pLoop->selFlags |= SF_Compound;
      }
      if( (p->selFlags & SF_MultiValue)==0 && 
        (mxSelect = pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT])>0 &&
        cnt>mxSelect
      ){
         diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of UNION or "\
                  "EXCEPT or INTERSECT operations", cnt,
                  pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT]);
         pParse->is_aborted = true;
      }
    }
  }
#line 964 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"

  /* This is a utility routine used to set the ExprSpan.zStart and
  ** ExprSpan.zEnd values of pOut so that the span covers the complete
  ** range of text beginning with pStart and going to the end of pEnd.
  */
  static void spanSet(ExprSpan *pOut, Token *pStart, Token *pEnd){
    pOut->zStart = pStart->z;
    pOut->zEnd = &pEnd->z[pEnd->n];
  }

  /* Construct a new Expr object from a single identifier.  Use the
  ** new Expr to populate pOut.  Set the span of pOut to be the identifier
  ** that created the expression.
  */
  static void spanExpr(ExprSpan *pOut, Parse *pParse, int op, Token t){
    struct Expr *p = NULL;
    int name_sz = t.n + 1;
    p = sqlDbMallocRawNN(pParse->db, sizeof(Expr) + name_sz);
    if( p ){
      memset(p, 0, sizeof(Expr));
      switch (op) {
      case TK_STRING:
        p->type = FIELD_TYPE_STRING;
        break;
      case TK_BLOB:
        p->type = FIELD_TYPE_VARBINARY;
        break;
      case TK_INTEGER:
        p->type = FIELD_TYPE_INTEGER;
        break;
      case TK_FLOAT:
        p->type = FIELD_TYPE_DOUBLE;
        break;
      case TK_TRUE:
      case TK_FALSE:
      case TK_UNKNOWN:
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      case TK_VARIABLE:
        /*
         * For variables we set BOOLEAN type since
         * unassigned bindings will be replaced
         * with NULL automatically, i.e. without
         * explicit call of sql_bind_*().
         */
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      default:
        p->type = FIELD_TYPE_SCALAR;
        break;
      }
      p->op = (u8)op;
      p->flags = EP_Leaf;
      p->iAgg = -1;
      p->u.zToken = (char*)&p[1];
      if (op != TK_VARIABLE) {
        int rc = sql_normalize_name(p->u.zToken, name_sz, t.z, t.n);
        if (rc > name_sz) {
          name_sz = rc;
          p = sqlDbReallocOrFree(pParse->db, p, sizeof(*p) + name_sz);
          if (p == NULL)
            goto tarantool_error;
          p->u.zToken = (char *) &p[1];
          if (sql_normalize_name(p->u.zToken, name_sz, t.z, t.n) > name_sz)
              unreachable();
        }
      } else {
        memcpy(p->u.zToken, t.z, t.n);
        p->u.zToken[t.n] = 0;
      }
#if SQL_MAX_EXPR_DEPTH>0
      p->nHeight = 1;
#endif  
    }
    pOut->pExpr = p;
    pOut->zStart = t.z;
    pOut->zEnd = &t.z[t.n];
    return;
tarantool_error:
    sqlDbFree(pParse->db, p);
    pParse->is_aborted = true;
  }
#line 1221 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"

  /* This routine constructs a binary expression node out of two ExprSpan
  ** objects and uses the result to populate a new ExprSpan object.
  */
  static void spanBinaryExpr(
    Parse *pParse,      /* The parsing context.  Errors accumulate here */
    int op,             /* The binary operation */
    ExprSpan *pLeft,    /* The left operand, and output */
    ExprSpan *pRight    /* The right operand */
  ){
    pLeft->pExpr = sqlPExpr(pParse, op, pLeft->pExpr, pRight->pExpr);
    pLeft->zEnd = pRight->zEnd;
  }

  /* If doNot is true, then add a TK_NOT Expr-node wrapper around the
  ** outside of *ppExpr.
  */
  static void exprNot(Parse *pParse, int doNot, ExprSpan *pSpan){
    if( doNot ){
      pSpan->pExpr = sqlPExpr(pParse, TK_NOT, pSpan->pExpr, 0);
    }
  }
#line 1295 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"

  /* Construct an expression node for a unary postfix operator
  */
  static void spanUnaryPostfix(
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand, and output */
    Token *pPostOp         /* The operand token for setting the span */
  ){
    pOperand->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOperand->zEnd = &pPostOp->z[pPostOp->n];
  }                           
#line 1316 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"

  /* Construct an expression node for a unary prefix operator
  */
  static void spanUnaryPrefix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPreOp         /* The operand token for setting the span */
  ){
    pOut->zStart = pPreOp->z;
    pOut->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOut->zEnd = pOperand->zEnd;
  }
#line 1518 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"

  /* Add a single new term to an ExprList that is used to store a
  ** list of identifiers.  Report an error if the ID list contains
  ** a COLLATE clause or an ASC or DESC keyword, except ignore the
  ** error while parsing a legacy schema.
  */
  static ExprList *parserAddExprIdListTerm(
    Parse *pParse,
    ExprList *pPrior,
    Token *pIdToken
  ){
    ExprList *p = sql_expr_list_append(pParse->db, pPrior, NULL);
    sqlExprListSetName(pParse, p, pIdToken, 1);
    return p;
  }
#line 1734 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"

  struct alter_args {
    struct SrcList *table_name;
    /** Name of constraint OR new name of table in case of RENAME. */
    struct Token name;
  };
#line 276 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next sections is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    sqlParserTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is sqlParserTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 271
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 76
#define sqlParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlParserTOKENTYPE yy0;
  struct ExprList * yy3;
  struct LimitVal yy4;
  ExprSpan yy82;
  With* yy91;
  Select* yy99;
  int yy112;
  ExprList* yy142;
  struct Expr * yy299;
  struct Token yy307;
  struct SrcList * yy308;
  struct type_def yy330;
  SrcList* yy367;
  enum trim_side_mask yy385;
  IdList* yy420;
  Expr* yy422;
  struct TrigEvent yy450;
  bool yy497;
  TriggerStep* yy527;
  struct alter_args yy530;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlParserARG_SDECL Parse *pParse;
#define sqlParserARG_PDECL ,Parse *pParse
#define sqlParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlParserARG_STORE yypParser->pParse = pParse
#define YYFALLBACK 1
#define YYNSTATE             436
#define YYNRULE              316
#define YY_MAX_SHIFT         435
#define YY_MIN_SHIFTREDUCE   656
#define YY_MAX_SHIFTREDUCE   971
#define YY_MIN_REDUCE        972
#define YY_MAX_REDUCE        1287
#define YY_ERROR_ACTION      1288
#define YY_ACCEPT_ACTION     1289
#define YY_NO_ACTION         1290
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (1581)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    65,   66,  292,  312,  837,  837,  847,  850,   63,   63,
 /*    10 */    64,   64,   64,   64,  770,   62,   62,   62,   62,   61,
 /*    20 */    61,   60,   60,   60,   59,  313,   64,   64,   64,   64,
 /*    30 */    57,   62,   62,   62,   62,   61,   61,   60,   60,   60,
 /*    40 */    59,  313,  961,   48,  961,   46,  674,  674,   65,   66,
 /*    50 */   292,  312,  837,  837,  847,  850,   63,   63,   64,   64,
 /*    60 */    64,   64,  910,   62,   62,   62,   62,   61,   61,   60,
 /*    70 */    60,   60,   59,  313,  195,   58,   56,  188,   65,   66,
 /*    80 */   292,  312,  837,  837,  847,  850,   63,   63,   64,   64,
 /*    90 */    64,   64,  221,   62,   62,   62,   62,   61,   61,   60,
 /*   100 */    60,   60,   59,  313,  742,  305,   52,   62,   62,   62,
 /*   110 */    62,   61,   61,   60,   60,   60,   59,  313,  704,  674,
 /*   120 */   674,   42,  313,   49,   50,  429,  374,  674,  674,  130,
 /*   130 */    51,  705,  931,   61,   61,   60,   60,   60,   59,  313,
 /*   140 */    67,  419,    4,   99,   99,  194,  807,  229,  314,  314,
 /*   150 */   273,  122,  306,  796,  677,  773,  774,  908,  315,  753,
 /*   160 */   315,  159,  882,  287,  881,  122,  400,  408,  290,  113,
 /*   170 */   247,  348,  341,  315,  947,  163,  273,  287,  802,  753,
 /*   180 */   403,  401,  290,   64,   64,   64,   64,  947,   62,   62,
 /*   190 */    62,   62,   61,   61,   60,   60,   60,   59,  313,  328,
 /*   200 */   421, 1289,  435,    1,  248,  130,  804,  925,  926,  927,
 /*   210 */   928,  929,  930,  275,  934,  935,  936,  936,  937,  785,
 /*   220 */   806,  806,  808,  809,  810,  811,  812,  427,  423,  822,
 /*   230 */   823,  824,  965,   21,   65,   66,  292,  312,  837,  837,
 /*   240 */   847,  850,   63,   63,   64,   64,   64,   64,  417,   62,
 /*   250 */    62,   62,   62,   61,   61,   60,   60,   60,   59,  313,
 /*   260 */    65,   66,  292,  312,  837,  837,  847,  850,   63,   63,
 /*   270 */    64,   64,   64,   64,  413,   62,   62,   62,   62,   61,
 /*   280 */    61,   60,   60,   60,   59,  313,   66,  292,  312,  837,
 /*   290 */   837,  847,  850,   63,   63,   64,   64,   64,   64,  913,
 /*   300 */    62,   62,   62,   62,   61,   61,   60,   60,   60,   59,
 /*   310 */   313,  657,  317,  690,   60,   60,   60,   59,  313,   65,
 /*   320 */    66,  292,  312,  837,  837,  847,  850,   63,   63,   64,
 /*   330 */    64,   64,   64,  429,   62,   62,   62,   62,   61,   61,
 /*   340 */    60,   60,   60,   59,  313,   59,  313,  952,  291,  768,
 /*   350 */   911,   97,   97,  952,  698,  699,  700,  687,  685,  377,
 /*   360 */   684,  376,  216,  875,   65,   66,  292,  312,  837,  837,
 /*   370 */   847,  850,   63,   63,   64,   64,   64,   64,  429,   62,
 /*   380 */    62,   62,   62,   61,   61,   60,   60,   60,   59,  313,
 /*   390 */   690,  434,  434,  228,  384,  283,   82,   82,  131,  127,
 /*   400 */   257,  256,  800,  678,   58,   56,  188,  402,  421,   65,
 /*   410 */    66,  292,  312,  837,  837,  847,  850,   63,   63,   64,
 /*   420 */    64,   64,   64,  429,   62,   62,   62,   62,   61,   61,
 /*   430 */    60,   60,   60,   59,  313,  727,  911,  151,   71,  257,
 /*   440 */   256,   97,   97,  838,  838,  848,  851,  800,  828,  422,
 /*   450 */    53,   20,  753,  421,   65,   66,  292,  312,  837,  837,
 /*   460 */   847,  850,   63,   63,   64,   64,   64,   64,  342,   62,
 /*   470 */    62,   62,   62,   61,   61,   60,   60,   60,   59,  313,
 /*   480 */   318,  915,  320,  189,  189,    7,  171,  170,  121,  961,
 /*   490 */   286,  961,  235,  801,  323,  387,  680,  272,  421,   65,
 /*   500 */    66,  292,  312,  837,  837,  847,  850,   63,   63,   64,
 /*   510 */    64,   64,   64,  297,   62,   62,   62,   62,   61,   61,
 /*   520 */    60,   60,   60,   59,  313,   65,   66,  292,  312,  837,
 /*   530 */   837,  847,  850,   63,   63,   64,   64,   64,   64,  221,
 /*   540 */    62,   62,   62,   62,   61,   61,   60,   60,   60,   59,
 /*   550 */   313,   65,   66,  292,  312,  837,  837,  847,  850,   63,
 /*   560 */    63,   64,   64,   64,   64,  679,   62,   62,   62,   62,
 /*   570 */    61,   61,   60,   60,   60,   59,  313,   65,   66,  292,
 /*   580 */   312,  837,  837,  847,  850,   63,   63,   64,   64,   64,
 /*   590 */    64,  308,   62,   62,   62,   62,   61,   61,   60,   60,
 /*   600 */    60,   59,  313,   52,  189,  189,  148,  961,  902,  961,
 /*   610 */   169,  168,  674,  674,  304,  686,  387,  257,  256,  899,
 /*   620 */    49,   50,  113,  899,  903,  325,  113,   51, 1266,   69,
 /*   630 */    44,  336, 1266,  807,  904,  720,  343,  885,  419,    4,
 /*   640 */  1178,  130,  721,  807,  970,  314,  314,  349,  673,  952,
 /*   650 */   291,  349,  818,  319,  740,  952,   47,  221,  767,  687,
 /*   660 */   351,  229,  166,  262,  408,  802,   72,  358, 1266,  123,
 /*   670 */   885,  347,   58,   56,  188,  802,  255,  292,  312,  837,
 /*   680 */   837,  847,  850,   63,   63,   64,   64,   64,   64,  220,
 /*   690 */    62,   62,   62,   62,   61,   61,   60,   60,   60,   59,
 /*   700 */   313,  719,  719,  804,   58,   56,  188,  806,  806,  808,
 /*   710 */   809,  810,  811,   58,   56,  188,  696,  806,  806,  808,
 /*   720 */   809,  810,  811,  812,  427,  423,  962,  962,  201,  965,
 /*   730 */    21,   65,   66,  292,  312,  837,  837,  847,  850,   63,
 /*   740 */    63,   64,   64,   64,   64,  379,   62,   62,   62,   62,
 /*   750 */    61,   61,   60,   60,   60,   59,  313,   65,   55,  292,
 /*   760 */   312,  837,  837,  847,  850,   63,   63,   64,   64,   64,
 /*   770 */    64,   52,   62,   62,   62,   62,   61,   61,   60,   60,
 /*   780 */    60,   59,  313,  697,  963,  756,  672,  149,   49,   50,
 /*   790 */  1005,  351,  130,  674,  674,   51,  308,  433,  426,  661,
 /*   800 */   432,  231,  284,  796,  747,  667,  419,    4,  800,  130,
 /*   810 */   130,  807,  389,  314,  314,  113,  754,  769,  737,  304,
 /*   820 */   236,  338,   52,  736,  126,  674,  674,  394,   73,  429,
 /*   830 */   174,  186,  408,  800,  674,  674,  228,  384,  366,   49,
 /*   840 */    50,  741,  326,  802,  771,  772,   51,   24,   24, 1236,
 /*   850 */  1236,  429,  717,  717,  248,  176,  333,  419,    4,  207,
 /*   860 */   289,  294,  807,  877,  314,  314,  229,  166,  262,   99,
 /*   870 */    99,  804,  672,  690,  298,  177,  754,  429,   58,   56,
 /*   880 */   188,  255,  334,  408,  426,  806,  806,  808,  809,  810,
 /*   890 */   811,  812,  427,  423,  802,   79,   79,  965,   21,  299,
 /*   900 */   383,  429,  732,  732,  421,  199,  403,  385,  391,  429,
 /*   910 */   406,  429,  329,  362,  359,  807,  962,  962,  381,   99,
 /*   920 */    99,  113,  804,  255,  197,  154,  421,   99,   99,   99,
 /*   930 */    99,  346,  382,  261,  902,  388,  806,  806,  808,  809,
 /*   940 */   810,  811,  812,  427,  423,   52,  260,  802,  965,   21,
 /*   950 */   903,  392,  421,   23,   23,  130,  403,  390,  179,  429,
 /*   960 */   904,  407,   49,   50,  403,  399,  403,  420,  873,   51,
 /*   970 */   879,  674,  674,  353,  963,  755,  421,   99,   99,  796,
 /*   980 */   419,    4,  753,  753,  421,  807,  421,  314,  314,  806,
 /*   990 */   806,  808,  809,  810,  811,  912,  247,  348,  372,  370,
 /*  1000 */   376,  295,  429,  912,  753,  130,  408,  429,  793,  429,
 /*  1010 */   421,  113,  369,  429,  403,  380,  873,  802,  429,  227,
 /*  1020 */    26,   26,  202,  203,  429,   24,   24,   24,   24,   28,
 /*  1030 */   248,   99,   99,  303,  421,  429,   99,   99,  335,  300,
 /*  1040 */     2,  302,   24,   24,  905,  804,  674,  674,  357,  301,
 /*  1050 */   753,  429,  753,   75,   75,  753,  397,  429,  357,  806,
 /*  1060 */   806,  808,  809,  810,  811,  812,  427,  423,  309,   84,
 /*  1070 */    84,  965,   21,  395,  949,   85,   85,  421,  673,  714,
 /*  1080 */   187,  186,  421,  729,  421,  429,  264,  714,  421,  429,
 /*  1090 */   874,  181,  723,  421,  387,  722,  429,  948,  429,  421,
 /*  1100 */   429,  673,  429,   86,   86,  429,  753,   87,   87,  429,
 /*  1110 */   421,  429,  873,  800,   88,   88,   27,   27,   76,   76,
 /*  1120 */    78,   78,  429,   89,   89,  429,  421,   90,   90,   91,
 /*  1130 */    91,  897,  421,  429,  113,  429,  805,  429,  206,  429,
 /*  1140 */    25,   25,  266,   92,   92,  311,  243,  429,  246,  429,
 /*  1150 */   268,   93,   93,   94,   94,   80,   80,   95,   95,  726,
 /*  1160 */   421,   39,  113,  429,  421,   96,   96,   81,   81,  773,
 /*  1170 */   774,  421,  429,  421,  175,  421,  429,  421,  357,  310,
 /*  1180 */   421,  118,  118,  429,  421,  429,  421,  429,  190,  410,
 /*  1190 */   119,  119,  113,  414,  120,  120,  113,  421,  429,  271,
 /*  1200 */   421,  103,  103,   98,   98,   83,   83,  429,  421,  429,
 /*  1210 */   421,  429,  421,  429,  421,  429,  106,  106,  960,  172,
 /*  1220 */   173,  429,  421,  429,  421,  100,  100,  107,  107,  105,
 /*  1230 */   105,  117,  117,  112,  112,  429,  355,  429,  421,  111,
 /*  1240 */   111,  110,  110,  418,  241,  429,  113,  421,  156,  252,
 /*  1250 */   990,  421,  429,  108,  108,  109,  109,  234,  421,  429,
 /*  1260 */   421,  184,  421,  102,  102,  754,   10,  737,  209,  428,
 /*  1270 */   104,  104,  736,  421,  429,  919,  164,  101,  101,  356,
 /*  1280 */   710,  429,  421,  914,  421,  321,  421,   41,  421,  223,
 /*  1290 */   421,  868,   74,   74,  688,  688,  421,  917,  421,   77,
 /*  1300 */    77,  240,  788,  798,  350,  352,  251,  219,  219,  219,
 /*  1310 */   421,  909,  421,  867,  711,  367,  907,   41,  713,  223,
 /*  1320 */   421,  918,   41,  330,  177,  754,  712,  421,  703,  702,
 /*  1330 */    35,  734,  763,  871,  421,   43,  219,  223,  944,  813,
 /*  1340 */   813,  841,   12,  239,  296,  331,  332,  238,  337,  421,
 /*  1350 */   237,  339,  244,  180,  245,  896,  421,  894,  354,  893,
 /*  1360 */   360,  361,  250,  666,  254,  259,  761,  799,  683,  270,
 /*  1370 */   743,  409,  872,  274,    9,  280,  165,  675,  664,  293,
 /*  1380 */   663,  665,  114,  155,  146,  135,  124,  784,  137,  340,
 /*  1390 */    39,  233,   30,  139,  204,  141,  880,  345,  365,  242,
 /*  1400 */   205,  157,  212,  213,  373,  363,  214,  115,  142,  307,
 /*  1410 */   253,  150,  795,  375,  708,  693,  116,  694,  258,  378,
 /*  1420 */   898,  707,  682,  681,  393,    8,   45,   38,  855,  425,
 /*  1430 */   222,  933,   68,  398,  412,  416,   40,  396,  431,  281,
 /*  1440 */   945,    5,  288,  941,  282,  230,  232,   11,   70,  751,
 /*  1450 */   659,  316,  943,  916,   13,   29,  263,  191,  733,  132,
 /*  1460 */   192,  322,  324,  752,  265,  276,  277,  278,  750,  267,
 /*  1470 */   279,  749,  269,  193,  196,  133,  878,  198,  167,  327,
 /*  1480 */   134,  794,  200,  136,  128,  138,  140,  724,  883,  344,
 /*  1490 */   219,  144,  143,  967,  892,  145,  147,   31,   32,   33,
 /*  1500 */    34,  129,  895,  891,  210,  208,   22,  211,   14,  249,
 /*  1510 */   158,  669,  364,  260,  215,  152,  368,   15,   16,  371,
 /*  1520 */   706,   36,  217,  172,  125,  173,  827,   37,  731,  386,
 /*  1530 */   182,  825,  853,   17,  757,  735,  183,    6,  842,  185,
 /*  1540 */   153,  411,  218,  424,  866,  404,  762,   43,   18,   41,
 /*  1550 */   854,  852,   19,  819,  901,  900,  405,  178,  415,  923,
 /*  1560 */   160,  224,  924,  857,  161,  226,  856,  162,  430,  826,
 /*  1570 */   225,  660,  815,    3,  285,  932,  814,   54,  656, 1254,
 /*  1580 */   670,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*    10 */    15,   16,   17,   18,  184,   20,   21,   22,   23,   24,
 /*    20 */    25,   26,   27,   28,   29,   30,   15,   16,   17,   18,
 /*    30 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*    40 */    29,   30,   47,  135,   49,  137,   49,   50,    5,    6,
 /*    50 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*    60 */    17,   18,  169,   20,   21,   22,   23,   24,   25,   26,
 /*    70 */    27,   28,   29,   30,   77,  245,  246,  247,    5,    6,
 /*    80 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*    90 */    17,   18,   97,   20,   21,   22,   23,   24,   25,   26,
 /*   100 */    27,   28,   29,   30,   26,   85,    7,   20,   21,   22,
 /*   110 */    23,   24,   25,   26,   27,   28,   29,   30,   57,   49,
 /*   120 */    50,   48,   30,   24,   25,  169,   65,   49,   50,   45,
 /*   130 */    31,   70,   75,   24,   25,   26,   27,   28,   29,   30,
 /*   140 */    67,   42,   43,  187,  188,  148,   47,   77,   49,   50,
 /*   150 */   169,  169,   91,   69,  187,  112,  113,  264,  176,  169,
 /*   160 */   178,  179,   54,  181,   56,  169,  210,   68,  186,  213,
 /*   170 */    86,   87,   64,  191,  178,  179,  169,  181,   79,  169,
 /*   180 */   224,  225,  186,   15,   16,   17,   18,  191,   20,   21,
 /*   190 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  209,
 /*   200 */   244,  163,  164,  165,  120,   45,  107,  150,  151,  152,
 /*   210 */   153,  154,  155,  156,  157,  158,  159,  160,  161,  209,
 /*   220 */   121,  122,  123,  124,  125,  126,  127,  128,  129,  130,
 /*   230 */   131,  132,  133,  134,    5,    6,    7,    8,    9,   10,
 /*   240 */    11,   12,   13,   14,   15,   16,   17,   18,  267,   20,
 /*   250 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   260 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   270 */    15,   16,   17,   18,  267,   20,   21,   22,   23,   24,
 /*   280 */    25,   26,   27,   28,   29,   30,    6,    7,    8,    9,
 /*   290 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   44,
 /*   300 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   310 */    30,    1,    2,   84,   26,   27,   28,   29,   30,    5,
 /*   320 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   330 */    16,   17,   18,  169,   20,   21,   22,   23,   24,   25,
 /*   340 */    26,   27,   28,   29,   30,   29,   30,  185,  186,  190,
 /*   350 */   183,  187,  188,  191,   88,   89,   90,  195,   44,   80,
 /*   360 */    81,   82,   83,  187,    5,    6,    7,    8,    9,   10,
 /*   370 */    11,   12,   13,   14,   15,   16,   17,   18,  169,   20,
 /*   380 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   390 */    84,  166,  167,  102,  103,  170,  187,  188,  194,  174,
 /*   400 */   196,  197,  169,   44,  245,  246,  247,  243,  244,    5,
 /*   410 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   420 */    16,   17,   18,  169,   20,   21,   22,   23,   24,   25,
 /*   430 */    26,   27,   28,   29,   30,  210,  269,  194,  213,  196,
 /*   440 */   197,  187,  188,    9,   10,   11,   12,  169,   44,  240,
 /*   450 */   241,  242,  169,  244,    5,    6,    7,    8,    9,   10,
 /*   460 */    11,   12,   13,   14,   15,   16,   17,   18,  235,   20,
 /*   470 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   480 */    80,   81,   82,  211,  212,   43,  261,  262,  263,   47,
 /*   490 */   265,   49,  209,   44,   94,  223,  187,  243,  244,    5,
 /*   500 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   510 */    16,   17,   18,  235,   20,   21,   22,   23,   24,   25,
 /*   520 */    26,   27,   28,   29,   30,    5,    6,    7,    8,    9,
 /*   530 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   97,
 /*   540 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   550 */    30,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   560 */    14,   15,   16,   17,   18,  187,   20,   21,   22,   23,
 /*   570 */    24,   25,   26,   27,   28,   29,   30,    5,    6,    7,
 /*   580 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   590 */    18,    7,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   600 */    28,   29,   30,    7,  211,  212,   43,   47,   35,   49,
 /*   610 */    24,   25,   49,   50,   30,  194,  223,  196,  197,  210,
 /*   620 */    24,   25,  213,  210,   51,  236,  213,   31,   44,   43,
 /*   630 */   136,  238,   48,   47,   61,   62,   86,   87,   42,   43,
 /*   640 */    44,   45,   69,   47,  180,   49,   50,  238,  184,  185,
 /*   650 */   186,  238,  106,  266,  227,  191,  136,   97,  190,  195,
 /*   660 */   169,   77,   78,   79,   68,   79,  253,  258,   84,   97,
 /*   670 */   120,  258,  245,  246,  247,   79,   92,    7,    8,    9,
 /*   680 */    10,   11,   12,   13,   14,   15,   16,   17,   18,  227,
 /*   690 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   700 */    30,  206,  207,  107,  245,  246,  247,  121,  122,  123,
 /*   710 */   124,  125,  126,  245,  246,  247,  198,  121,  122,  123,
 /*   720 */   124,  125,  126,  127,  128,  129,   49,   50,  237,  133,
 /*   730 */   134,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   740 */    14,   15,   16,   17,   18,   26,   20,   21,   22,   23,
 /*   750 */    24,   25,   26,   27,   28,   29,   30,    5,    6,    7,
 /*   760 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   770 */    18,    7,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   780 */    28,   29,   30,  198,  107,  108,  183,   43,   24,   25,
 /*   790 */     1,  169,   45,   49,   50,   31,    7,   32,  183,   34,
 /*   800 */    35,   36,   37,   69,  230,   40,   42,   43,  169,   45,
 /*   810 */    45,   47,  210,   49,   50,  213,   48,  184,   99,   30,
 /*   820 */    86,   87,    7,  104,   53,   49,   50,  234,   43,  169,
 /*   830 */   228,  229,   68,  169,   49,   50,  102,  103,    7,   24,
 /*   840 */    25,   26,   71,   79,   73,   74,   31,  187,  188,  102,
 /*   850 */   103,  169,  206,  207,  120,  234,   91,   42,   43,  237,
 /*   860 */    95,  201,   47,   44,   49,   50,   77,   78,   79,  187,
 /*   870 */   188,  107,  269,   84,  235,  107,  108,  169,  245,  246,
 /*   880 */   247,   92,  117,   68,  269,  121,  122,  123,  124,  125,
 /*   890 */   126,  127,  128,  129,   79,  187,  188,  133,  134,  235,
 /*   900 */    98,  169,  100,  101,  244,  140,  224,  225,    7,  169,
 /*   910 */   207,  169,  147,  251,  252,   47,   49,   50,  210,  187,
 /*   920 */   188,  213,  107,   92,  105,  149,  244,  187,  188,  187,
 /*   930 */   188,  255,  224,   79,   35,  169,  121,  122,  123,  124,
 /*   940 */   125,  126,  127,  128,  129,    7,   92,   79,  133,  134,
 /*   950 */    51,   50,  244,  187,  188,   45,  224,  225,  254,  169,
 /*   960 */    61,   62,   24,   25,  224,  225,  224,  225,  169,   31,
 /*   970 */    60,   49,   50,  169,  107,  108,  244,  187,  188,   69,
 /*   980 */    42,   43,  169,  169,  244,   47,  244,   49,   50,  121,
 /*   990 */   122,  123,  124,  125,  126,  195,   86,   87,   80,   81,
 /*  1000 */    82,  202,  169,  203,  169,   45,   68,  169,  210,  169,
 /*  1010 */   244,  213,   94,  169,  224,  225,  169,   79,  169,  216,
 /*  1020 */   187,  188,  209,  209,  169,  187,  188,  187,  188,  226,
 /*  1030 */   120,  187,  188,  200,  244,  169,  187,  188,   78,  201,
 /*  1040 */    43,  201,  187,  188,  209,  107,   49,   50,  169,  202,
 /*  1050 */   169,  169,  169,  187,  188,  169,  201,  169,  169,  121,
 /*  1060 */   122,  123,  124,  125,  126,  127,  128,  129,  224,  187,
 /*  1070 */   188,  133,  134,  224,  180,  187,  188,  244,  184,  195,
 /*  1080 */   228,  229,  244,  212,  244,  169,  227,  203,  244,  169,
 /*  1090 */   209,   48,  209,  244,  223,  209,  169,  180,  169,  244,
 /*  1100 */   169,  184,  169,  187,  188,  169,  169,  187,  188,  169,
 /*  1110 */   244,  169,  169,  169,  187,  188,  187,  188,  187,  188,
 /*  1120 */   187,  188,  169,  187,  188,  169,  244,  187,  188,  187,
 /*  1130 */   188,  210,  244,  169,  213,  169,  169,  169,  259,  169,
 /*  1140 */   187,  188,  227,  187,  188,  202,  209,  169,  259,  169,
 /*  1150 */   227,  187,  188,  187,  188,  187,  188,  187,  188,  210,
 /*  1160 */   244,  118,  213,  169,  244,  187,  188,  187,  188,  112,
 /*  1170 */   113,  244,  169,  244,  169,  244,  169,  244,  169,  235,
 /*  1180 */   244,  187,  188,  169,  244,  169,  244,  169,   43,  210,
 /*  1190 */   187,  188,  213,  210,  187,  188,  213,  244,  169,  169,
 /*  1200 */   244,  187,  188,  187,  188,  187,  188,  169,  244,  169,
 /*  1210 */   244,  169,  244,  169,  244,  169,  187,  188,   48,   86,
 /*  1220 */    87,  169,  244,  169,  244,  187,  188,  187,  188,  187,
 /*  1230 */   188,  187,  188,  187,  188,  169,    7,  169,  244,  187,
 /*  1240 */   188,  187,  188,  210,   39,  169,  213,  244,  214,   39,
 /*  1250 */   105,  244,  169,  187,  188,  187,  188,  169,  244,  169,
 /*  1260 */   244,   44,  244,  187,  188,   48,  215,   99,  259,    7,
 /*  1270 */   187,  188,  104,  244,  169,  169,  106,  187,  188,   50,
 /*  1280 */    59,  169,  244,   44,  244,   44,  244,   48,  244,   48,
 /*  1290 */   244,   81,  187,  188,   49,   50,  244,  169,  244,  187,
 /*  1300 */   188,   96,  218,   44,   44,   44,   96,   48,   48,   48,
 /*  1310 */   244,  169,  244,   44,   93,   44,  169,   48,   44,   48,
 /*  1320 */   244,  169,   48,  169,  107,  108,   44,  244,   78,   79,
 /*  1330 */    48,   44,   44,   44,  244,   48,   48,   48,   44,   49,
 /*  1340 */    50,   79,   48,  138,  169,  169,  169,  142,  231,  244,
 /*  1350 */   231,  169,  142,  169,  260,  218,  244,  169,  260,  169,
 /*  1360 */   169,  169,  169,  169,  169,  169,  169,  169,  190,  231,
 /*  1370 */   169,  250,  169,  169,  215,  217,  215,  169,  169,    9,
 /*  1380 */   169,  169,  193,   43,   43,  239,    5,  218,  205,   41,
 /*  1390 */   118,  192,  135,  208,  208,  208,  257,  144,   41,  256,
 /*  1400 */   175,  239,  175,  175,   85,  192,  175,  193,  208,   63,
 /*  1410 */   192,  205,  205,   85,  199,  196,  193,  197,  192,   85,
 /*  1420 */   218,  199,  189,  189,  110,   43,  135,   85,  248,   43,
 /*  1430 */   249,  268,  116,  111,  192,  192,  115,  114,   46,   45,
 /*  1440 */   177,   43,  172,   36,  171,  168,  168,  182,  182,  233,
 /*  1450 */     4,    3,  173,   66,   43,   43,  232,   83,  222,   43,
 /*  1460 */    77,   66,   82,  233,  232,  221,  220,  219,  233,  232,
 /*  1470 */   218,  233,  232,   38,   77,   39,   44,   43,   14,   95,
 /*  1480 */    39,  103,  139,  119,   91,  106,   85,   42,  143,  145,
 /*  1490 */    48,   85,  143,  146,    1,  106,  119,   14,   14,   14,
 /*  1500 */    14,   91,   50,    1,  105,  109,  141,   85,   43,  138,
 /*  1510 */    97,   42,    7,   92,   83,   43,   66,   43,   43,   66,
 /*  1520 */    52,   43,   66,   86,   58,   87,   44,   48,   99,   48,
 /*  1530 */   105,   44,   44,   43,  108,   44,   44,   43,   79,   44,
 /*  1540 */    43,   97,  109,  126,   44,   47,   50,   48,  109,   48,
 /*  1550 */    44,   44,  109,  106,   44,   44,   48,   43,   97,   44,
 /*  1560 */    43,   48,   44,   60,   43,  105,   44,   43,   14,   44,
 /*  1570 */    43,   33,   44,   43,   38,   44,   44,   43,    1,    0,
 /*  1580 */    47,
};
#define YY_SHIFT_USE_DFLT (1581)
#define YY_SHIFT_COUNT    (435)
#define YY_SHIFT_MIN      (-92)
#define YY_SHIFT_MAX      (1579)
static const short yy_shift_ofst[] = {
 /*     0 */   310,  765,  596,   99,  764,   70,  938,  938,  938,  938,
 /*    10 */   938,  789,   70,  938,  938,  938,  938,  938,  938,  938,
 /*    20 */   938,  938,   84,   -5,   43,   43,  229,  229,  815,  938,
 /*    30 */   938,  938,  938,  938,  938,  938,  938,  938,  938,  938,
 /*    40 */   938,  938,  938,  938,  938,  938,  938,  938,  938,  938,
 /*    50 */   938,  938,  938,  938,  938,  938,  938,  938,  938,  938,
 /*    60 */   938,  938,  938,  938,  938,  938,  938,  938,  938,  938,
 /*    70 */   584,  734,  910,  747,   73,  255,  314,  359,  404,  449,
 /*    80 */   494,  520,  546,  572,  726,  726,  726,  726,  726,  726,
 /*    90 */   726,  726,  726,  726,  726,  726,  726,  726,  726,  726,
 /*   100 */   752,  726,  280,  670,  670,   11,  168,  168,  168,   87,
 /*   110 */   109,  288,  316,  291,   20,   20,   20,   92, 1581, 1581,
 /*   120 */  1581,   57,   57,   57,  573,  573,   -3, 1210,  563,  563,
 /*   130 */   776,  831,  922,  922,  922,  960,  922,  922,  922,  922,
 /*   140 */   922,  922,  922,  922,  922,  922,  922,  922,  922,  922,
 /*   150 */   922,  831,  922,  922,  922,  922,  291,  160,  160,  306,
 /*   160 */   160,  160,  160,  306, 1581, 1581,  586,  868,  868,  868,
 /*   170 */   400,  771,   61,   61, 1217,  442,  677,  867,  899,  550,
 /*   180 */   108,  744,   78,  560,  560,  560,  785,  768,  997,  802,
 /*   190 */   719,  922,  922,  922,  922,  922,  922,  922,  922,  922,
 /*   200 */   922, 1043,  901,  901,  922,  922, 1229, 1043,  922, 1229,
 /*   210 */   922,  922,  922,  922,  922,  922,  922, 1057,  922,  922,
 /*   220 */   901,  922,  -92,  922,  922, 1168,  922, 1170, 1168,  922,
 /*   230 */   922,  922,  922, 1370, 1340, 1341, 1381, 1272, 1348, 1348,
 /*   240 */  1348, 1348, 1257, 1253, 1357, 1272, 1341, 1381, 1381, 1357,
 /*   250 */  1340, 1357, 1357, 1370, 1340, 1346, 1319, 1328, 1370, 1340,
 /*   260 */  1346, 1334, 1334, 1314, 1342, 1314, 1342, 1314, 1342, 1314,
 /*   270 */  1342, 1382, 1291, 1340, 1340, 1386, 1316, 1322, 1321, 1323,
 /*   280 */  1272, 1392, 1394, 1398, 1407, 1407, 1581, 1581, 1581, 1205,
 /*   290 */   918,  279,  434,  266, 1239, 1241,  819, 1259, 1260, 1261,
 /*   300 */  1269, 1271, 1274, 1282, 1245, 1133, 1250, 1221,  854, 1287,
 /*   310 */  1288, 1289, 1262, 1290, 1145, 1294, 1446, 1448, 1387, 1411,
 /*   320 */  1412, 1374, 1416, 1395, 1383, 1380, 1435, 1397, 1384, 1436,
 /*   330 */  1432, 1434, 1464, 1343, 1441, 1378, 1364, 1393, 1379, 1401,
 /*   340 */  1445, 1345, 1442, 1349, 1347, 1344, 1406, 1493, 1389, 1377,
 /*   350 */  1483, 1484, 1485, 1486, 1410, 1452, 1396, 1399, 1502, 1365,
 /*   360 */  1465, 1422, 1371, 1413, 1469, 1505, 1421, 1431, 1472, 1450,
 /*   370 */  1474, 1475, 1453, 1437, 1468, 1438, 1478, 1456, 1466, 1482,
 /*   380 */  1487, 1488, 1479, 1429, 1490, 1491, 1494, 1481, 1425, 1492,
 /*   390 */  1495, 1496, 1433, 1497, 1426, 1499, 1439, 1501, 1443, 1500,
 /*   400 */  1506, 1507, 1447, 1499, 1510, 1498, 1508, 1511, 1514, 1503,
 /*   410 */  1515, 1517, 1444, 1513, 1518, 1521, 1461, 1513, 1522, 1524,
 /*   420 */  1525, 1527, 1528, 1530, 1531, 1417, 1532, 1534, 1459, 1460,
 /*   430 */  1533, 1554, 1536, 1538, 1577, 1579,
};
#define YY_REDUCE_USE_DFLT (-171)
#define YY_REDUCE_COUNT (288)
#define YY_REDUCE_MIN   (-170)
#define YY_REDUCE_MAX   (1279)
static const short yy_reduce_ofst[] = {
 /*     0 */    38,  225,  -44,  209,  708,  -18,  682,  732,  740,  742,
 /*    10 */   790,  464,   -4,  660,  838,  840,  833,  844,  849,  855,
 /*    20 */   164,  254,  413,  427,  159,  468, -170,  633,  766,  866,
 /*    30 */   882,  888,  916,  920,  927,  929,  931,  933,  936,  940,
 /*    40 */   942,  953,  956,  964,  966,  968,  970,  978,  980,  994,
 /*    50 */  1003, 1007, 1014, 1016, 1018, 1029, 1038, 1040, 1042, 1044,
 /*    60 */  1046, 1052, 1054, 1066, 1068, 1076, 1083, 1090, 1105, 1112,
 /*    70 */   162,  393,  409,  602,  459,  459,  459,  459,  459,  459,
 /*    80 */   459,  459,  459,  459,  459,  459,  459,  459,  459,  459,
 /*    90 */   459,  459,  459,  459,  459,  459,  459,  459,  459,  459,
 /*   100 */   459,  459,  459,  459,  459,  459,  459,  459,  459,  459,
 /*   110 */   459,  459,  459,  272,  204,  243,  421,  459,  459,  459,
 /*   120 */   459,  167,  603,  615,  495,  646, -107,  662,  491,  622,
 /*   130 */   -19,  800,  799,  -10,   10,  798,  283,  813,  814,  835,
 /*   140 */   881,  883,  886,  233,  937,  879,  278,  889,  639,  664,
 /*   150 */  1009,  884,  847,  944,    7,  943,  871,  921,  949,  894,
 /*   160 */   979,  983, 1033,  917,  852,  803,  -33,  176,  309,  378,
 /*   170 */   387,  389,  518,  585,  574,  462,  593,  621,  703,  676,
 /*   180 */   704,  804,  967,  859,  915,  923, 1005,  574, 1030, 1034,
 /*   190 */  1051, 1088, 1106, 1128, 1142, 1147, 1152, 1154, 1175, 1176,
 /*   200 */  1177, 1084, 1117, 1119, 1182, 1184, 1094, 1137, 1188, 1098,
 /*   210 */  1190, 1191, 1192, 1193, 1194, 1195, 1196, 1178, 1197, 1198,
 /*   220 */  1138, 1201, 1121, 1203, 1204, 1159,  967, 1158, 1161, 1208,
 /*   230 */  1209, 1211, 1212, 1189, 1199, 1146, 1183, 1169, 1185, 1186,
 /*   240 */  1187, 1200, 1139, 1143, 1225, 1202, 1162, 1206, 1207, 1227,
 /*   250 */  1213, 1228, 1231, 1214, 1218, 1215, 1219, 1220, 1223, 1226,
 /*   260 */  1222, 1233, 1234, 1216, 1224, 1230, 1232, 1235, 1237, 1238,
 /*   270 */  1240, 1180, 1181, 1242, 1243, 1163, 1236, 1244, 1246, 1248,
 /*   280 */  1252, 1263, 1270, 1273, 1277, 1278, 1265, 1266, 1279,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1255, 1236, 1236, 1288, 1236,  992, 1178, 1178, 1178, 1178,
 /*    10 */  1178,  992,  992, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    20 */  1136, 1136, 1236, 1060, 1091, 1091, 1005, 1005, 1288, 1288,
 /*    30 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    40 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    50 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    60 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    70 */   992, 1288, 1236, 1064, 1097, 1288, 1288, 1288, 1179, 1180,
 /*    80 */  1288, 1288, 1133, 1288, 1206, 1108, 1107, 1106, 1105, 1074,
 /*    90 */  1103, 1095, 1099, 1179, 1175, 1176, 1174, 1137, 1132, 1180,
 /*   100 */  1288, 1098, 1146, 1159, 1145, 1155, 1165, 1156, 1148, 1147,
 /*   110 */  1149, 1150, 1151, 1288, 1011, 1011, 1011, 1152, 1162, 1161,
 /*   120 */  1160, 1288, 1288, 1288, 1288, 1288, 1288, 1185, 1288, 1288,
 /*   130 */  1288, 1031, 1288, 1288, 1288, 1236, 1288, 1288, 1288, 1288,
 /*   140 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   150 */  1288, 1031, 1288, 1288, 1288, 1288, 1288, 1236, 1236, 1005,
 /*   160 */  1236, 1236, 1236, 1005, 1064, 1055, 1288, 1288, 1288, 1288,
 /*   170 */  1288, 1288, 1288, 1288, 1288, 1060, 1288, 1288, 1288, 1288,
 /*   180 */  1200, 1288, 1288, 1060, 1060, 1060, 1288, 1062, 1288, 1044,
 /*   190 */  1054, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   200 */  1288, 1102, 1076, 1076, 1288, 1288, 1285, 1102, 1288, 1285,
 /*   210 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1091, 1288, 1288,
 /*   220 */  1076, 1288, 1177, 1288, 1288, 1054, 1288, 1061, 1054, 1288,
 /*   230 */  1288, 1288, 1288, 1017, 1186, 1113, 1034, 1102, 1041, 1041,
 /*   240 */  1041, 1041, 1205, 1204,  984, 1102, 1113, 1034, 1034,  984,
 /*   250 */  1186,  984,  984, 1017, 1186, 1025, 1008, 1007, 1017, 1186,
 /*   260 */  1025, 1032, 1032, 1080, 1075, 1080, 1075, 1080, 1075, 1080,
 /*   270 */  1075, 1181, 1288, 1186, 1186, 1288, 1096, 1081, 1094, 1092,
 /*   280 */  1102, 1288, 1262, 1288, 1258, 1258, 1269, 1269,  987, 1288,
 /*   290 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   300 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   310 */  1288, 1288, 1288, 1288, 1119, 1288, 1288,  974, 1288, 1288,
 /*   320 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1222, 1288,
 /*   330 */  1288, 1192, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   340 */  1288, 1288, 1203, 1202, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   350 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1284, 1288, 1288,
 /*   360 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   370 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   380 */  1288, 1288, 1288, 1046, 1288, 1288, 1288, 1275, 1288, 1288,
 /*   390 */  1288, 1288, 1288, 1288, 1288, 1093, 1288, 1082, 1288, 1288,
 /*   400 */  1288, 1288, 1288, 1282, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   410 */  1288, 1288, 1288, 1238, 1288, 1288, 1288, 1237, 1288, 1288,
 /*   420 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   430 */  1288, 1288,  978, 1288, 1288, 1288,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
    0,  /*    EXPLAIN => nothing */
   49,  /*      QUERY => ID */
   49,  /*       PLAN => ID */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*        NOT => nothing */
    0,  /*         IS => nothing */
   49,  /*      MATCH => ID */
    0,  /*    LIKE_KW => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*      START => nothing */
    0,  /* TRANSACTION => nothing */
    0,  /*     COMMIT => nothing */
    0,  /*   ROLLBACK => nothing */
    0,  /*  SAVEPOINT => nothing */
   49,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   49,  /*         IF => ID */
    0,  /*     EXISTS => nothing */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*       WITH => nothing */
   49,  /*     ENGINE => ID */
    0,  /*     STRING => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   49,  /*      ABORT => ID */
   49,  /*     ACTION => ID */
   49,  /*        ADD => ID */
   49,  /*      AFTER => ID */
   49,  /* AUTOINCREMENT => ID */
   49,  /*     BEFORE => ID */
   49,  /*    CASCADE => ID */
   49,  /*   CONFLICT => ID */
   49,  /*   DEFERRED => ID */
   49,  /*        END => ID */
   49,  /*       FAIL => ID */
   49,  /*     IGNORE => ID */
   49,  /*  INITIALLY => ID */
   49,  /*    INSTEAD => ID */
   49,  /*         NO => ID */
   49,  /*        KEY => ID */
   49,  /*     OFFSET => ID */
   49,  /*      RAISE => ID */
   49,  /*    REPLACE => ID */
   49,  /*   RESTRICT => ID */
   49,  /*     RENAME => ID */
   49,  /*   CTIME_KW => ID */
   49,  /*     ENABLE => ID */
   49,  /*    DISABLE => ID */
   49,  /*       UUID => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  bool is_fallback_failed;      /* Shows if fallback failed or not */
  sqlParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "OR",            "AND",           "NOT",         
  "IS",            "MATCH",         "LIKE_KW",       "BETWEEN",     
  "IN",            "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "BITNOT",      
  "START",         "TRANSACTION",   "COMMIT",        "ROLLBACK",    
  "SAVEPOINT",     "RELEASE",       "TO",            "TABLE",       
  "CREATE",        "IF",            "EXISTS",        "LP",          
  "RP",            "WITH",          "ENGINE",        "STRING",      
  "COMMA",         "ID",            "INDEXED",       "ABORT",       
  "ACTION",        "ADD",           "AFTER",         "AUTOINCREMENT",
  "BEFORE",        "CASCADE",       "CONFLICT",      "DEFERRED",    
  "END",           "FAIL",          "IGNORE",        "INITIALLY",   
  "INSTEAD",       "NO",            "KEY",           "OFFSET",      
  "RAISE",         "REPLACE",       "RESTRICT",      "RENAME",      
  "CTIME_KW",      "ENABLE",        "DISABLE",       "UUID",        
  "ANY",           "CONSTRAINT",    "DEFAULT",       "NULL",        
  "PRIMARY",       "UNIQUE",        "CHECK",         "REFERENCES",  
  "AUTOINCR",      "ON",            "UPDATE",        "DELETE",      
  "SIMPLE",        "PARTIAL",       "FULL",          "SET",         
  "DEFERRABLE",    "IMMEDIATE",     "FOREIGN",       "DROP",        
  "VIEW",          "AS",            "UNION",         "ALL",         
  "EXCEPT",        "INTERSECT",     "SELECT",        "VALUES",      
  "DISTINCT",      "DOT",           "FROM",          "JOIN_KW",     
  "JOIN",          "BY",            "USING",         "ORDER",       
  "ASC",           "DESC",          "GROUP",         "HAVING",      
  "LIMIT",         "TRUNCATE",      "WHERE",         "INTO",        
  "INSERT",        "FLOAT",         "BLOB",          "FALSE",       
  "TRUE",          "UNKNOWN",       "INTEGER",       "VARIABLE",    
  "CAST",          "TRIM",          "LEADING",       "TRAILING",    
  "BOTH",          "CHAR",          "CASE",          "WHEN",        
  "THEN",          "ELSE",          "INDEX",         "SESSION",     
  "PRAGMA",        "BEGIN",         "TRIGGER",       "OF",          
  "FOR",           "EACH",          "ROW",           "ALTER",       
  "COLUMN",        "RECURSIVE",     "TEXT",          "STRING_KW",   
  "SCALAR",        "BOOL",          "BOOLEAN",       "VARBINARY",   
  "VARCHAR",       "NUMBER",        "DOUBLE",        "INT",         
  "INTEGER_KW",    "UNSIGNED",      "error",         "input",       
  "ecmd",          "explain",       "cmdx",          "cmd",         
  "savepoint_opt",  "nm",            "create_table",  "create_table_args",
  "with_opts",     "create_table_end",  "createkw",      "ifnotexists", 
  "columnlist",    "engine_opts",   "tcons",         "column_def",  
  "create_column_end",  "column_name_and_type",  "carglist",      "typedef",     
  "autoinc",       "ccons",         "cconsname",     "term",        
  "expr",          "onconf",        "sortorder",     "check_constraint_def",
  "eidlist_opt",   "matcharg",      "refargs",       "defer_subclause",
  "refact_update",  "refact_delete",  "refact",        "init_deferred_pred_opt",
  "col_list_with_autoinc",  "sortlist",      "eidlist",       "defer_subclause_opt",
  "index_onconf",  "orconf",        "resolvetype",   "raisetype",   
  "ifexists",      "fullname",      "select",        "selectnowith",
  "oneselect",     "with",          "multiselect_op",  "distinct",    
  "selcollist",    "from",          "where_opt",     "groupby_opt", 
  "having_opt",    "orderby_opt",   "limit_opt",     "values",      
  "nexprlist",     "exprlist",      "sclp",          "as",          
  "seltablist",    "stl_prefix",    "joinop",        "indexed_opt", 
  "on_opt",        "using_opt",     "join_nm",       "idlist",      
  "enable",        "setlist",       "insert_cmd",    "idlist_opt",  
  "trim_operands",  "trim_from_clause",  "trim_specification",  "expr_optional",
  "type_func",     "likeop",        "between_op",    "in_op",       
  "paren_exprlist",  "case_exprlist",  "case_else",     "uniqueflag",  
  "trigger_decl",  "trigger_cmd_list",  "trigger_time",  "trigger_event",
  "foreach_clause",  "when_clause",   "trigger_cmd",   "trnm",        
  "tridxby",       "alter_table_start",  "alter_add_constraint",  "alter_add_column",
  "column_name",   "alter_column_def",  "unique_spec",   "wqlist",      
  "char_len",      "number_typedef",
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "ecmd ::= explain cmdx SEMI",
 /*   1 */ "ecmd ::= SEMI",
 /*   2 */ "explain ::= EXPLAIN",
 /*   3 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   4 */ "cmd ::= START TRANSACTION",
 /*   5 */ "cmd ::= COMMIT",
 /*   6 */ "cmd ::= ROLLBACK",
 /*   7 */ "cmd ::= SAVEPOINT nm",
 /*   8 */ "cmd ::= RELEASE savepoint_opt nm",
 /*   9 */ "cmd ::= ROLLBACK TO savepoint_opt nm",
 /*  10 */ "create_table ::= createkw TABLE ifnotexists nm",
 /*  11 */ "createkw ::= CREATE",
 /*  12 */ "ifnotexists ::=",
 /*  13 */ "ifnotexists ::= IF NOT EXISTS",
 /*  14 */ "engine_opts ::= ENGINE EQ STRING",
 /*  15 */ "create_table_end ::=",
 /*  16 */ "column_name_and_type ::= nm typedef",
 /*  17 */ "create_column_end ::= autoinc",
 /*  18 */ "nm ::= ID|INDEXED",
 /*  19 */ "cconsname ::= CONSTRAINT nm",
 /*  20 */ "cconsname ::=",
 /*  21 */ "ccons ::= DEFAULT term",
 /*  22 */ "ccons ::= DEFAULT LP expr RP",
 /*  23 */ "ccons ::= DEFAULT PLUS term",
 /*  24 */ "ccons ::= DEFAULT MINUS term",
 /*  25 */ "ccons ::= NULL onconf",
 /*  26 */ "ccons ::= NOT NULL onconf",
 /*  27 */ "ccons ::= cconsname PRIMARY KEY sortorder",
 /*  28 */ "ccons ::= cconsname UNIQUE",
 /*  29 */ "check_constraint_def ::= cconsname CHECK LP expr RP",
 /*  30 */ "ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs",
 /*  31 */ "ccons ::= defer_subclause",
 /*  32 */ "ccons ::= COLLATE ID|INDEXED",
 /*  33 */ "autoinc ::=",
 /*  34 */ "autoinc ::= AUTOINCR",
 /*  35 */ "refargs ::= refact_update",
 /*  36 */ "refargs ::= refact_delete",
 /*  37 */ "refargs ::= refact_delete refact_update",
 /*  38 */ "refargs ::= refact_update refact_delete",
 /*  39 */ "refargs ::=",
 /*  40 */ "refact_update ::= ON UPDATE refact",
 /*  41 */ "refact_delete ::= ON DELETE refact",
 /*  42 */ "matcharg ::= MATCH SIMPLE",
 /*  43 */ "matcharg ::= MATCH PARTIAL",
 /*  44 */ "matcharg ::= MATCH FULL",
 /*  45 */ "matcharg ::=",
 /*  46 */ "refact ::= SET NULL",
 /*  47 */ "refact ::= SET DEFAULT",
 /*  48 */ "refact ::= CASCADE",
 /*  49 */ "refact ::= RESTRICT",
 /*  50 */ "refact ::= NO ACTION",
 /*  51 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  52 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  53 */ "init_deferred_pred_opt ::=",
 /*  54 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  55 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  56 */ "tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP",
 /*  57 */ "tcons ::= cconsname UNIQUE LP sortlist RP",
 /*  58 */ "tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /*  59 */ "defer_subclause_opt ::=",
 /*  60 */ "onconf ::=",
 /*  61 */ "onconf ::= ON CONFLICT resolvetype",
 /*  62 */ "orconf ::=",
 /*  63 */ "orconf ::= OR resolvetype",
 /*  64 */ "resolvetype ::= IGNORE",
 /*  65 */ "resolvetype ::= REPLACE",
 /*  66 */ "cmd ::= DROP TABLE ifexists fullname",
 /*  67 */ "cmd ::= DROP VIEW ifexists fullname",
 /*  68 */ "ifexists ::= IF EXISTS",
 /*  69 */ "ifexists ::=",
 /*  70 */ "cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select",
 /*  71 */ "cmd ::= select",
 /*  72 */ "select ::= with selectnowith",
 /*  73 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /*  74 */ "multiselect_op ::= UNION",
 /*  75 */ "multiselect_op ::= UNION ALL",
 /*  76 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /*  77 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /*  78 */ "values ::= VALUES LP nexprlist RP",
 /*  79 */ "values ::= values COMMA LP exprlist RP",
 /*  80 */ "distinct ::= DISTINCT",
 /*  81 */ "distinct ::= ALL",
 /*  82 */ "distinct ::=",
 /*  83 */ "sclp ::=",
 /*  84 */ "selcollist ::= sclp expr as",
 /*  85 */ "selcollist ::= sclp STAR",
 /*  86 */ "selcollist ::= sclp nm DOT STAR",
 /*  87 */ "as ::= AS nm",
 /*  88 */ "as ::=",
 /*  89 */ "from ::=",
 /*  90 */ "from ::= FROM seltablist",
 /*  91 */ "stl_prefix ::= seltablist joinop",
 /*  92 */ "stl_prefix ::=",
 /*  93 */ "seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt",
 /*  94 */ "seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt",
 /*  95 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /*  96 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /*  97 */ "fullname ::= nm",
 /*  98 */ "joinop ::= COMMA|JOIN",
 /*  99 */ "joinop ::= JOIN_KW JOIN",
 /* 100 */ "joinop ::= JOIN_KW join_nm JOIN",
 /* 101 */ "joinop ::= JOIN_KW join_nm join_nm JOIN",
 /* 102 */ "on_opt ::= ON expr",
 /* 103 */ "on_opt ::=",
 /* 104 */ "indexed_opt ::=",
 /* 105 */ "indexed_opt ::= INDEXED BY nm",
 /* 106 */ "indexed_opt ::= NOT INDEXED",
 /* 107 */ "using_opt ::= USING LP idlist RP",
 /* 108 */ "using_opt ::=",
 /* 109 */ "orderby_opt ::=",
 /* 110 */ "orderby_opt ::= ORDER BY sortlist",
 /* 111 */ "sortlist ::= sortlist COMMA expr sortorder",
 /* 112 */ "sortlist ::= expr sortorder",
 /* 113 */ "col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc",
 /* 114 */ "col_list_with_autoinc ::= expr autoinc",
 /* 115 */ "enable ::= ENABLE",
 /* 116 */ "enable ::= DISABLE",
 /* 117 */ "sortorder ::= ASC",
 /* 118 */ "sortorder ::= DESC",
 /* 119 */ "sortorder ::=",
 /* 120 */ "groupby_opt ::=",
 /* 121 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 122 */ "having_opt ::=",
 /* 123 */ "having_opt ::= HAVING expr",
 /* 124 */ "limit_opt ::=",
 /* 125 */ "limit_opt ::= LIMIT expr",
 /* 126 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 127 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 128 */ "cmd ::= with DELETE FROM fullname indexed_opt where_opt",
 /* 129 */ "cmd ::= TRUNCATE TABLE fullname",
 /* 130 */ "where_opt ::=",
 /* 131 */ "where_opt ::= WHERE expr",
 /* 132 */ "cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 133 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 134 */ "setlist ::= setlist COMMA LP idlist RP EQ expr",
 /* 135 */ "setlist ::= nm EQ expr",
 /* 136 */ "setlist ::= LP idlist RP EQ expr",
 /* 137 */ "cmd ::= with insert_cmd INTO fullname idlist_opt select",
 /* 138 */ "cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES",
 /* 139 */ "insert_cmd ::= INSERT orconf",
 /* 140 */ "insert_cmd ::= REPLACE",
 /* 141 */ "idlist_opt ::=",
 /* 142 */ "idlist_opt ::= LP idlist RP",
 /* 143 */ "idlist ::= idlist COMMA nm",
 /* 144 */ "idlist ::= nm",
 /* 145 */ "expr ::= LP expr RP",
 /* 146 */ "term ::= NULL",
 /* 147 */ "expr ::= ID|INDEXED",
 /* 148 */ "expr ::= JOIN_KW",
 /* 149 */ "expr ::= nm DOT nm",
 /* 150 */ "term ::= FLOAT|BLOB",
 /* 151 */ "term ::= STRING",
 /* 152 */ "term ::= FALSE",
 /* 153 */ "term ::= TRUE",
 /* 154 */ "term ::= UNKNOWN",
 /* 155 */ "term ::= INTEGER",
 /* 156 */ "expr ::= VARIABLE",
 /* 157 */ "expr ::= expr COLLATE ID|INDEXED",
 /* 158 */ "expr ::= CAST LP expr AS typedef RP",
 /* 159 */ "expr ::= TRIM LP trim_operands RP",
 /* 160 */ "trim_operands ::= trim_from_clause expr",
 /* 161 */ "trim_operands ::= expr",
 /* 162 */ "trim_from_clause ::= expr FROM",
 /* 163 */ "trim_from_clause ::= trim_specification expr_optional FROM",
 /* 164 */ "expr_optional ::=",
 /* 165 */ "expr_optional ::= expr",
 /* 166 */ "trim_specification ::= LEADING",
 /* 167 */ "trim_specification ::= TRAILING",
 /* 168 */ "trim_specification ::= BOTH",
 /* 169 */ "expr ::= ID|INDEXED LP distinct exprlist RP",
 /* 170 */ "expr ::= type_func LP distinct exprlist RP",
 /* 171 */ "expr ::= ID|INDEXED LP STAR RP",
 /* 172 */ "expr ::= LP nexprlist COMMA expr RP",
 /* 173 */ "expr ::= expr AND expr",
 /* 174 */ "expr ::= expr OR expr",
 /* 175 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 176 */ "expr ::= expr EQ|NE expr",
 /* 177 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 178 */ "expr ::= expr PLUS|MINUS expr",
 /* 179 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 180 */ "expr ::= expr CONCAT expr",
 /* 181 */ "likeop ::= LIKE_KW|MATCH",
 /* 182 */ "likeop ::= NOT LIKE_KW|MATCH",
 /* 183 */ "expr ::= expr likeop expr",
 /* 184 */ "expr ::= expr likeop expr ESCAPE expr",
 /* 185 */ "expr ::= expr IS NULL",
 /* 186 */ "expr ::= expr IS NOT NULL",
 /* 187 */ "expr ::= NOT expr",
 /* 188 */ "expr ::= BITNOT expr",
 /* 189 */ "expr ::= MINUS expr",
 /* 190 */ "expr ::= PLUS expr",
 /* 191 */ "between_op ::= BETWEEN",
 /* 192 */ "between_op ::= NOT BETWEEN",
 /* 193 */ "expr ::= expr between_op expr AND expr",
 /* 194 */ "in_op ::= IN",
 /* 195 */ "in_op ::= NOT IN",
 /* 196 */ "expr ::= expr in_op LP exprlist RP",
 /* 197 */ "expr ::= LP select RP",
 /* 198 */ "expr ::= expr in_op LP select RP",
 /* 199 */ "expr ::= expr in_op nm paren_exprlist",
 /* 200 */ "expr ::= EXISTS LP select RP",
 /* 201 */ "expr ::= CASE expr_optional case_exprlist case_else END",
 /* 202 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 203 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 204 */ "case_else ::= ELSE expr",
 /* 205 */ "case_else ::=",
 /* 206 */ "exprlist ::=",
 /* 207 */ "nexprlist ::= nexprlist COMMA expr",
 /* 208 */ "nexprlist ::= expr",
 /* 209 */ "paren_exprlist ::=",
 /* 210 */ "paren_exprlist ::= LP exprlist RP",
 /* 211 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP",
 /* 212 */ "uniqueflag ::= UNIQUE",
 /* 213 */ "uniqueflag ::=",
 /* 214 */ "eidlist_opt ::=",
 /* 215 */ "eidlist_opt ::= LP eidlist RP",
 /* 216 */ "eidlist ::= eidlist COMMA nm",
 /* 217 */ "eidlist ::= nm",
 /* 218 */ "cmd ::= DROP INDEX ifexists nm ON fullname",
 /* 219 */ "cmd ::= SET SESSION nm EQ term",
 /* 220 */ "cmd ::= PRAGMA nm",
 /* 221 */ "cmd ::= PRAGMA nm LP nm RP",
 /* 222 */ "cmd ::= PRAGMA nm LP nm DOT nm RP",
 /* 223 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 224 */ "trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 225 */ "trigger_time ::= BEFORE",
 /* 226 */ "trigger_time ::= AFTER",
 /* 227 */ "trigger_time ::= INSTEAD OF",
 /* 228 */ "trigger_time ::=",
 /* 229 */ "trigger_event ::= DELETE|INSERT",
 /* 230 */ "trigger_event ::= UPDATE",
 /* 231 */ "trigger_event ::= UPDATE OF idlist",
 /* 232 */ "foreach_clause ::=",
 /* 233 */ "when_clause ::=",
 /* 234 */ "when_clause ::= WHEN expr",
 /* 235 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 236 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 237 */ "trnm ::= nm DOT nm",
 /* 238 */ "tridxby ::= INDEXED BY nm",
 /* 239 */ "tridxby ::= NOT INDEXED",
 /* 240 */ "trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt",
 /* 241 */ "trigger_cmd ::= insert_cmd INTO trnm idlist_opt select",
 /* 242 */ "trigger_cmd ::= DELETE FROM trnm tridxby where_opt",
 /* 243 */ "trigger_cmd ::= select",
 /* 244 */ "expr ::= RAISE LP IGNORE RP",
 /* 245 */ "expr ::= RAISE LP raisetype COMMA STRING RP",
 /* 246 */ "raisetype ::= ROLLBACK",
 /* 247 */ "raisetype ::= ABORT",
 /* 248 */ "raisetype ::= FAIL",
 /* 249 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 250 */ "alter_table_start ::= ALTER TABLE fullname",
 /* 251 */ "alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm",
 /* 252 */ "alter_add_column ::= alter_table_start ADD column_name",
 /* 253 */ "column_name ::= COLUMN nm",
 /* 254 */ "column_name ::= nm",
 /* 255 */ "alter_column_def ::= alter_add_column typedef",
 /* 256 */ "cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /* 257 */ "cmd ::= alter_add_constraint CHECK LP expr RP",
 /* 258 */ "cmd ::= alter_add_constraint unique_spec LP sortlist RP",
 /* 259 */ "unique_spec ::= UNIQUE",
 /* 260 */ "unique_spec ::= PRIMARY KEY",
 /* 261 */ "cmd ::= alter_table_start RENAME TO nm",
 /* 262 */ "cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm",
 /* 263 */ "cmd ::= alter_table_start enable CHECK CONSTRAINT nm",
 /* 264 */ "with ::=",
 /* 265 */ "with ::= WITH wqlist",
 /* 266 */ "with ::= WITH RECURSIVE wqlist",
 /* 267 */ "wqlist ::= nm eidlist_opt AS LP select RP",
 /* 268 */ "wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP",
 /* 269 */ "typedef ::= TEXT",
 /* 270 */ "typedef ::= STRING_KW",
 /* 271 */ "typedef ::= SCALAR",
 /* 272 */ "typedef ::= BOOL",
 /* 273 */ "typedef ::= BOOLEAN",
 /* 274 */ "typedef ::= VARBINARY",
 /* 275 */ "typedef ::= UUID",
 /* 276 */ "char_len ::= LP INTEGER RP",
 /* 277 */ "typedef ::= VARCHAR char_len",
 /* 278 */ "number_typedef ::= NUMBER",
 /* 279 */ "number_typedef ::= DOUBLE",
 /* 280 */ "number_typedef ::= INT|INTEGER_KW",
 /* 281 */ "number_typedef ::= UNSIGNED",
 /* 282 */ "input ::= ecmd",
 /* 283 */ "explain ::=",
 /* 284 */ "cmdx ::= cmd",
 /* 285 */ "savepoint_opt ::= SAVEPOINT",
 /* 286 */ "savepoint_opt ::=",
 /* 287 */ "cmd ::= create_table create_table_args with_opts create_table_end",
 /* 288 */ "create_table_args ::= LP columnlist RP",
 /* 289 */ "with_opts ::= WITH engine_opts",
 /* 290 */ "with_opts ::=",
 /* 291 */ "columnlist ::= columnlist COMMA tcons",
 /* 292 */ "columnlist ::= columnlist COMMA column_def create_column_end",
 /* 293 */ "columnlist ::= column_def create_column_end",
 /* 294 */ "column_def ::= column_name_and_type carglist",
 /* 295 */ "columnlist ::= tcons",
 /* 296 */ "carglist ::= carglist ccons",
 /* 297 */ "carglist ::=",
 /* 298 */ "ccons ::= check_constraint_def",
 /* 299 */ "tcons ::= check_constraint_def",
 /* 300 */ "defer_subclause_opt ::= defer_subclause",
 /* 301 */ "resolvetype ::= raisetype",
 /* 302 */ "selectnowith ::= oneselect",
 /* 303 */ "oneselect ::= values",
 /* 304 */ "sclp ::= selcollist COMMA",
 /* 305 */ "as ::= ID|STRING",
 /* 306 */ "join_nm ::= ID|INDEXED",
 /* 307 */ "join_nm ::= JOIN_KW",
 /* 308 */ "expr ::= term",
 /* 309 */ "type_func ::= CHAR",
 /* 310 */ "exprlist ::= nexprlist",
 /* 311 */ "foreach_clause ::= FOR EACH ROW",
 /* 312 */ "trnm ::= nm",
 /* 313 */ "tridxby ::=",
 /* 314 */ "cmd ::= alter_column_def carglist create_column_end",
 /* 315 */ "typedef ::= number_typedef",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to sqlParserAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlParser and sqlParserFree.
*/
void *sqlParserAlloc(void *(*mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
    pParser->is_fallback_failed = false;
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
    case 187: /* term */
    case 188: /* expr */
{
#line 962 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy82).pExpr, false);
#line 1592 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
}
      break;
    case 192: /* eidlist_opt */
    case 200: /* col_list_with_autoinc */
    case 201: /* sortlist */
    case 202: /* eidlist */
    case 216: /* selcollist */
    case 219: /* groupby_opt */
    case 221: /* orderby_opt */
    case 224: /* nexprlist */
    case 225: /* exprlist */
    case 226: /* sclp */
    case 237: /* setlist */
    case 248: /* paren_exprlist */
    case 249: /* case_exprlist */
{
#line 1516 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy142));
#line 1611 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
}
      break;
    case 209: /* fullname */
    case 217: /* from */
    case 228: /* seltablist */
    case 229: /* stl_prefix */
{
#line 711 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
sqlSrcListDelete(pParse->db, (yypminor->yy367));
#line 1621 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
}
      break;
    case 210: /* select */
    case 211: /* selectnowith */
    case 212: /* oneselect */
    case 223: /* values */
{
#line 473 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
sql_select_delete(pParse->db, (yypminor->yy99));
#line 1631 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
}
      break;
    case 213: /* with */
    case 267: /* wqlist */
{
#line 1814 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
sqlWithDelete(pParse->db, (yypminor->yy91));
#line 1639 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
}
      break;
    case 218: /* where_opt */
    case 220: /* having_opt */
    case 232: /* on_opt */
    case 250: /* case_else */
    case 257: /* when_clause */
{
#line 871 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy422), false);
#line 1650 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
}
      break;
    case 233: /* using_opt */
    case 235: /* idlist */
    case 239: /* idlist_opt */
{
#line 754 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy420));
#line 1659 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
}
      break;
    case 240: /* trim_operands */
    case 241: /* trim_from_clause */
{
#line 1133 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy3));
#line 1667 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
}
      break;
    case 243: /* expr_optional */
{
#line 1164 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy299), false);
#line 1674 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
}
      break;
    case 253: /* trigger_cmd_list */
    case 258: /* trigger_cmd */
{
#line 1615 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
sqlDeleteTriggerStep(pParse->db, (yypminor->yy527));
#line 1682 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
}
      break;
    case 255: /* trigger_event */
{
#line 1596 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy450).b);
#line 1689 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void sqlParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback = -1;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      } else if ( iFallback==0 ) {
        pParser->is_fallback_failed = true;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   sqlParserARG_FETCH;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
#line 44 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"

  diag_set(ClientError, ER_SQL_STACK_OVERFLOW);
  pParse->is_aborted = true;
#line 1865 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
/******** End %stack_overflow code ********************************************/
   sqlParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  sqlParserTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yypParser->yytos--;
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yypParser->yytos--;
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 164, 3 },
  { 164, 1 },
  { 165, 1 },
  { 165, 3 },
  { 167, 2 },
  { 167, 1 },
  { 167, 1 },
  { 167, 2 },
  { 167, 3 },
  { 167, 4 },
  { 170, 4 },
  { 174, 1 },
  { 175, 0 },
  { 175, 3 },
  { 177, 3 },
  { 173, 0 },
  { 181, 2 },
  { 180, 1 },
  { 169, 1 },
  { 186, 2 },
  { 186, 0 },
  { 185, 2 },
  { 185, 4 },
  { 185, 3 },
  { 185, 3 },
  { 185, 2 },
  { 185, 3 },
  { 185, 4 },
  { 185, 2 },
  { 191, 5 },
  { 185, 6 },
  { 185, 1 },
  { 185, 2 },
  { 184, 0 },
  { 184, 1 },
  { 194, 1 },
  { 194, 1 },
  { 194, 2 },
  { 194, 2 },
  { 194, 0 },
  { 196, 3 },
  { 197, 3 },
  { 193, 2 },
  { 193, 2 },
  { 193, 2 },
  { 193, 0 },
  { 198, 2 },
  { 198, 2 },
  { 198, 1 },
  { 198, 1 },
  { 198, 2 },
  { 195, 3 },
  { 195, 2 },
  { 199, 0 },
  { 199, 2 },
  { 199, 2 },
  { 178, 6 },
  { 178, 5 },
  { 178, 12 },
  { 203, 0 },
  { 189, 0 },
  { 189, 3 },
  { 205, 0 },
  { 205, 2 },
  { 206, 1 },
  { 206, 1 },
  { 167, 4 },
  { 167, 4 },
  { 208, 2 },
  { 208, 0 },
  { 167, 7 },
  { 167, 1 },
  { 210, 2 },
  { 211, 3 },
  { 214, 1 },
  { 214, 2 },
  { 214, 1 },
  { 212, 9 },
  { 223, 4 },
  { 223, 5 },
  { 215, 1 },
  { 215, 1 },
  { 215, 0 },
  { 226, 0 },
  { 216, 3 },
  { 216, 2 },
  { 216, 4 },
  { 227, 2 },
  { 227, 0 },
  { 217, 0 },
  { 217, 2 },
  { 229, 2 },
  { 229, 0 },
  { 228, 6 },
  { 228, 8 },
  { 228, 7 },
  { 228, 7 },
  { 209, 1 },
  { 230, 1 },
  { 230, 2 },
  { 230, 3 },
  { 230, 4 },
  { 232, 2 },
  { 232, 0 },
  { 231, 0 },
  { 231, 3 },
  { 231, 2 },
  { 233, 4 },
  { 233, 0 },
  { 221, 0 },
  { 221, 3 },
  { 201, 4 },
  { 201, 2 },
  { 200, 4 },
  { 200, 2 },
  { 236, 1 },
  { 236, 1 },
  { 190, 1 },
  { 190, 1 },
  { 190, 0 },
  { 219, 0 },
  { 219, 3 },
  { 220, 0 },
  { 220, 2 },
  { 222, 0 },
  { 222, 2 },
  { 222, 4 },
  { 222, 4 },
  { 167, 6 },
  { 167, 3 },
  { 218, 0 },
  { 218, 2 },
  { 167, 8 },
  { 237, 5 },
  { 237, 7 },
  { 237, 3 },
  { 237, 5 },
  { 167, 6 },
  { 167, 7 },
  { 238, 2 },
  { 238, 1 },
  { 239, 0 },
  { 239, 3 },
  { 235, 3 },
  { 235, 1 },
  { 188, 3 },
  { 187, 1 },
  { 188, 1 },
  { 188, 1 },
  { 188, 3 },
  { 187, 1 },
  { 187, 1 },
  { 187, 1 },
  { 187, 1 },
  { 187, 1 },
  { 187, 1 },
  { 188, 1 },
  { 188, 3 },
  { 188, 6 },
  { 188, 4 },
  { 240, 2 },
  { 240, 1 },
  { 241, 2 },
  { 241, 3 },
  { 243, 0 },
  { 243, 1 },
  { 242, 1 },
  { 242, 1 },
  { 242, 1 },
  { 188, 5 },
  { 188, 5 },
  { 188, 4 },
  { 188, 5 },
  { 188, 3 },
  { 188, 3 },
  { 188, 3 },
  { 188, 3 },
  { 188, 3 },
  { 188, 3 },
  { 188, 3 },
  { 188, 3 },
  { 245, 1 },
  { 245, 2 },
  { 188, 3 },
  { 188, 5 },
  { 188, 3 },
  { 188, 4 },
  { 188, 2 },
  { 188, 2 },
  { 188, 2 },
  { 188, 2 },
  { 246, 1 },
  { 246, 2 },
  { 188, 5 },
  { 247, 1 },
  { 247, 2 },
  { 188, 5 },
  { 188, 3 },
  { 188, 5 },
  { 188, 4 },
  { 188, 4 },
  { 188, 5 },
  { 249, 5 },
  { 249, 4 },
  { 250, 2 },
  { 250, 0 },
  { 225, 0 },
  { 224, 3 },
  { 224, 1 },
  { 248, 0 },
  { 248, 3 },
  { 167, 10 },
  { 251, 1 },
  { 251, 0 },
  { 192, 0 },
  { 192, 3 },
  { 202, 3 },
  { 202, 1 },
  { 167, 6 },
  { 167, 5 },
  { 167, 2 },
  { 167, 5 },
  { 167, 7 },
  { 167, 5 },
  { 252, 9 },
  { 254, 1 },
  { 254, 1 },
  { 254, 2 },
  { 254, 0 },
  { 255, 1 },
  { 255, 1 },
  { 255, 3 },
  { 256, 0 },
  { 257, 0 },
  { 257, 2 },
  { 253, 3 },
  { 253, 2 },
  { 259, 3 },
  { 260, 3 },
  { 260, 2 },
  { 258, 7 },
  { 258, 5 },
  { 258, 5 },
  { 258, 1 },
  { 188, 4 },
  { 188, 6 },
  { 207, 1 },
  { 207, 1 },
  { 207, 1 },
  { 167, 4 },
  { 261, 3 },
  { 262, 4 },
  { 263, 3 },
  { 264, 2 },
  { 264, 1 },
  { 265, 2 },
  { 167, 12 },
  { 167, 5 },
  { 167, 5 },
  { 266, 1 },
  { 266, 2 },
  { 167, 4 },
  { 167, 6 },
  { 167, 5 },
  { 213, 0 },
  { 213, 2 },
  { 213, 3 },
  { 267, 6 },
  { 267, 8 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 268, 3 },
  { 183, 2 },
  { 269, 1 },
  { 269, 1 },
  { 269, 1 },
  { 269, 1 },
  { 163, 1 },
  { 165, 0 },
  { 166, 1 },
  { 168, 1 },
  { 168, 0 },
  { 167, 4 },
  { 171, 3 },
  { 172, 2 },
  { 172, 0 },
  { 176, 3 },
  { 176, 4 },
  { 176, 2 },
  { 179, 2 },
  { 176, 1 },
  { 182, 2 },
  { 182, 0 },
  { 185, 1 },
  { 178, 1 },
  { 203, 1 },
  { 206, 1 },
  { 211, 1 },
  { 212, 1 },
  { 226, 2 },
  { 227, 1 },
  { 234, 1 },
  { 234, 1 },
  { 188, 1 },
  { 244, 1 },
  { 225, 1 },
  { 256, 3 },
  { 259, 1 },
  { 260, 0 },
  { 167, 3 },
  { 183, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlParserARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* ecmd ::= explain cmdx SEMI */
#line 123 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
	if (!pParse->parse_only)
		sql_finish_coding(pParse);
}
#line 2324 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 1: /* ecmd ::= SEMI */
#line 127 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_STATEMENT_EMPTY);
  pParse->is_aborted = true;
}
#line 2332 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 2: /* explain ::= EXPLAIN */
#line 132 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ pParse->explain = 1; }
#line 2337 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 3: /* explain ::= EXPLAIN QUERY PLAN */
#line 133 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ pParse->explain = 2; }
#line 2342 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 4: /* cmd ::= START TRANSACTION */
#line 163 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{sql_transaction_begin(pParse);}
#line 2347 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 5: /* cmd ::= COMMIT */
#line 164 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{sql_transaction_commit(pParse);}
#line 2352 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 6: /* cmd ::= ROLLBACK */
#line 165 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{sql_transaction_rollback(pParse);}
#line 2357 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 7: /* cmd ::= SAVEPOINT nm */
#line 169 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2364 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 8: /* cmd ::= RELEASE savepoint_opt nm */
#line 172 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2371 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 9: /* cmd ::= ROLLBACK TO savepoint_opt nm */
#line 175 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2378 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 10: /* create_table ::= createkw TABLE ifnotexists nm */
#line 182 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_table_def_init(&pParse->create_table_def, &yymsp[0].minor.yy0, yymsp[-1].minor.yy112);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  pParse->create_table_def.new_space = sqlStartTable(pParse, &yymsp[0].minor.yy0);
  pParse->initiateTTrans = true;
}
#line 2389 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 11: /* createkw ::= CREATE */
#line 189 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{disableLookaside(pParse);}
#line 2394 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 12: /* ifnotexists ::= */
      case 33: /* autoinc ::= */ yytestcase(yyruleno==33);
      case 53: /* init_deferred_pred_opt ::= */ yytestcase(yyruleno==53);
      case 59: /* defer_subclause_opt ::= */ yytestcase(yyruleno==59);
      case 69: /* ifexists ::= */ yytestcase(yyruleno==69);
      case 82: /* distinct ::= */ yytestcase(yyruleno==82);
#line 192 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy112 = 0;}
#line 2404 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 13: /* ifnotexists ::= IF NOT EXISTS */
#line 193 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-2].minor.yy112 = 1;}
#line 2409 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 14: /* engine_opts ::= ENGINE EQ STRING */
#line 200 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  /* Note that specifying engine clause overwrites default engine. */
  if (yymsp[0].minor.yy0.n > ENGINE_NAME_MAX) {
    diag_set(ClientError, ER_CREATE_SPACE,
             pParse->create_table_def.new_space->def->name,
             "space engine name is too long");
    pParse->is_aborted = true;
    return;
  }
  /* Need to dequote name. */
  char *normalized_name = sql_name_from_token(pParse->db, &yymsp[0].minor.yy0);
  if (normalized_name == NULL)
    return;
  memcpy(pParse->create_table_def.new_space->def->engine_name, normalized_name,
         strlen(normalized_name) + 1);
  sqlDbFree(pParse->db, normalized_name);
}
#line 2430 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 15: /* create_table_end ::= */
#line 218 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ sqlEndTable(pParse); }
#line 2435 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 16: /* column_name_and_type ::= nm typedef */
#line 236 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, NULL, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy330);
  sql_create_column_start(pParse);
}
#line 2443 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 17: /* create_column_end ::= autoinc */
#line 241 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  uint32_t fieldno = pParse->create_column_def.space->def->field_count - 1;
  if (yymsp[0].minor.yy112 == 1 && sql_add_autoincrement(pParse, fieldno) != 0)
    return;
  if (pParse->create_table_def.new_space == NULL)
    sql_create_column_end(pParse);
}
#line 2454 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 18: /* nm ::= ID|INDEXED */
#line 283 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  if(yymsp[0].minor.yy0.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z);
    pParse->is_aborted = true;
  }
}
#line 2465 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 19: /* cconsname ::= CONSTRAINT nm */
#line 299 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy307 = yymsp[0].minor.yy0; }
#line 2470 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 20: /* cconsname ::= */
#line 300 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[1].minor.yy307 = Token_nil; }
#line 2475 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 21: /* ccons ::= DEFAULT term */
      case 23: /* ccons ::= DEFAULT PLUS term */ yytestcase(yyruleno==23);
#line 301 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[0].minor.yy82);}
#line 2481 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 22: /* ccons ::= DEFAULT LP expr RP */
#line 302 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[-1].minor.yy82);}
#line 2486 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 24: /* ccons ::= DEFAULT MINUS term */
#line 304 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  ExprSpan v;
  v.pExpr = sqlPExpr(pParse, TK_UMINUS, yymsp[0].minor.yy82.pExpr, 0);
  v.zStart = yymsp[-1].minor.yy0.z;
  v.zEnd = yymsp[0].minor.yy82.zEnd;
  sqlAddDefaultValue(pParse,&v);
}
#line 2497 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 25: /* ccons ::= NULL onconf */
#line 315 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
    sql_column_add_nullable_action(pParse, ON_CONFLICT_ACTION_NONE);
    /* Trigger nullability mismatch error if required. */
    if (yymsp[0].minor.yy112 != ON_CONFLICT_ACTION_ABORT)
        sql_column_add_nullable_action(pParse, yymsp[0].minor.yy112);
}
#line 2507 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 26: /* ccons ::= NOT NULL onconf */
#line 321 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{sql_column_add_nullable_action(pParse, yymsp[0].minor.yy112);}
#line 2512 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 27: /* ccons ::= cconsname PRIMARY KEY sortorder */
#line 322 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-3].minor.yy307, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, yymsp[0].minor.yy112, false);
  sqlAddPrimaryKey(pParse);
}
#line 2521 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 28: /* ccons ::= cconsname UNIQUE */
#line 327 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-1].minor.yy307, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2531 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 29: /* check_constraint_def ::= cconsname CHECK LP expr RP */
#line 336 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_ck_def_init(&pParse->create_ck_def, NULL, &yymsp[-4].minor.yy307, &yymsp[-1].minor.yy82);
  sql_create_check_contraint(pParse);
}
#line 2539 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 30: /* ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs */
#line 341 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-5].minor.yy307, NULL, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy142, yymsp[-1].minor.yy112, yymsp[0].minor.yy112,
                     false);
  sql_create_foreign_key(pParse);
}
#line 2548 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 31: /* ccons ::= defer_subclause */
#line 346 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{fk_constraint_change_defer_mode(pParse, yymsp[0].minor.yy112);}
#line 2553 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 32: /* ccons ::= COLLATE ID|INDEXED */
#line 347 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{sqlAddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2558 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 34: /* autoinc ::= AUTOINCR */
#line 352 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = 1;}
#line 2563 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 35: /* refargs ::= refact_update */
#line 360 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yylhsminor.yy112 = (yymsp[0].minor.yy112 << 8); }
#line 2568 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[0].minor.yy112 = yylhsminor.yy112;
        break;
      case 36: /* refargs ::= refact_delete */
#line 361 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yylhsminor.yy112 = yymsp[0].minor.yy112; }
#line 2574 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[0].minor.yy112 = yylhsminor.yy112;
        break;
      case 37: /* refargs ::= refact_delete refact_update */
#line 362 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yylhsminor.yy112 = (yymsp[0].minor.yy112 << 8) | (yymsp[-1].minor.yy112) ; }
#line 2580 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-1].minor.yy112 = yylhsminor.yy112;
        break;
      case 38: /* refargs ::= refact_update refact_delete */
#line 363 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yylhsminor.yy112 = (yymsp[-1].minor.yy112 << 8) | (yymsp[0].minor.yy112) ; }
#line 2586 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-1].minor.yy112 = yylhsminor.yy112;
        break;
      case 39: /* refargs ::= */
#line 364 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[1].minor.yy112 = 0; }
#line 2592 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 40: /* refact_update ::= ON UPDATE refact */
      case 41: /* refact_delete ::= ON DELETE refact */ yytestcase(yyruleno==41);
#line 367 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-2].minor.yy112 = yymsp[0].minor.yy112; }
#line 2598 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 42: /* matcharg ::= MATCH SIMPLE */
#line 372 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_MATCH_SIMPLE; }
#line 2603 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 43: /* matcharg ::= MATCH PARTIAL */
#line 373 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_MATCH_PARTIAL; }
#line 2608 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 44: /* matcharg ::= MATCH FULL */
#line 374 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_MATCH_FULL; }
#line 2613 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 45: /* matcharg ::= */
#line 375 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[1].minor.yy112 = FKEY_MATCH_SIMPLE; }
#line 2618 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 46: /* refact ::= SET NULL */
#line 378 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_ACTION_SET_NULL; }
#line 2623 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 47: /* refact ::= SET DEFAULT */
#line 379 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_ACTION_SET_DEFAULT; }
#line 2628 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 48: /* refact ::= CASCADE */
#line 380 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = FKEY_ACTION_CASCADE; }
#line 2633 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 49: /* refact ::= RESTRICT */
#line 381 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = FKEY_ACTION_RESTRICT; }
#line 2638 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 50: /* refact ::= NO ACTION */
#line 382 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_NO_ACTION; }
#line 2643 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 51: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
#line 384 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-2].minor.yy112 = 0;}
#line 2648 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 52: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 63: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==63);
      case 139: /* insert_cmd ::= INSERT orconf */ yytestcase(yyruleno==139);
#line 385 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-1].minor.yy112 = yymsp[0].minor.yy112;}
#line 2655 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 54: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 68: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==68);
      case 192: /* between_op ::= NOT BETWEEN */ yytestcase(yyruleno==192);
      case 195: /* in_op ::= NOT IN */ yytestcase(yyruleno==195);
#line 388 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-1].minor.yy112 = 1;}
#line 2663 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 55: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
#line 389 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-1].minor.yy112 = 0;}
#line 2668 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 56: /* tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP */
#line 391 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-5].minor.yy307, yymsp[-1].minor.yy142,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, SORT_ORDER_ASC, false);
  sqlAddPrimaryKey(pParse);
}
#line 2677 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 57: /* tcons ::= cconsname UNIQUE LP sortlist RP */
#line 396 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy307, yymsp[-1].minor.yy142,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2687 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 58: /* tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 404 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-11].minor.yy307, yymsp[-7].minor.yy142, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy142, yymsp[-2].minor.yy112, yymsp[-1].minor.yy112, yymsp[0].minor.yy112);
  sql_create_foreign_key(pParse);
}
#line 2695 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 60: /* onconf ::= */
#line 419 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy112 = ON_CONFLICT_ACTION_ABORT;}
#line 2700 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 61: /* onconf ::= ON CONFLICT resolvetype */
#line 420 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-2].minor.yy112 = yymsp[0].minor.yy112;}
#line 2705 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 62: /* orconf ::= */
#line 421 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy112 = ON_CONFLICT_ACTION_DEFAULT;}
#line 2710 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 64: /* resolvetype ::= IGNORE */
#line 424 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = ON_CONFLICT_ACTION_IGNORE;}
#line 2715 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 65: /* resolvetype ::= REPLACE */
      case 140: /* insert_cmd ::= REPLACE */ yytestcase(yyruleno==140);
#line 425 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = ON_CONFLICT_ACTION_REPLACE;}
#line 2721 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 66: /* cmd ::= DROP TABLE ifexists fullname */
#line 430 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_table_def_init(&pParse->drop_table_def, yymsp[0].minor.yy367, &t, yymsp[-1].minor.yy112);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2731 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 67: /* cmd ::= DROP VIEW ifexists fullname */
#line 437 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_view_def_init(&pParse->drop_view_def, yymsp[0].minor.yy367, &t, yymsp[-1].minor.yy112);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2741 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 70: /* cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select */
#line 451 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  if (!pParse->parse_only) {
    create_view_def_init(&pParse->create_view_def, &yymsp[-3].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-2].minor.yy142, yymsp[0].minor.yy99, yymsp[-4].minor.yy112);
    pParse->initiateTTrans = true;
    sql_create_view(pParse);
  } else {
    sql_store_select(pParse, yymsp[0].minor.yy99);
  }
}
#line 2754 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 71: /* cmd ::= select */
#line 463 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0, 0, 0};
  if(!pParse->parse_only)
          sqlSelect(pParse, yymsp[0].minor.yy99, &dest);
  else
          sql_expr_extract_select(pParse, yymsp[0].minor.yy99);
  sql_select_delete(pParse->db, yymsp[0].minor.yy99);
}
#line 2766 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 72: /* select ::= with selectnowith */
#line 506 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  Select *p = yymsp[0].minor.yy99;
  if( p ){
    p->pWith = yymsp[-1].minor.yy91;
    parserDoubleLinkSelect(pParse, p);
  }else{
    sqlWithDelete(pParse->db, yymsp[-1].minor.yy91);
  }
  yymsp[-1].minor.yy99 = p; /*A-overwrites-W*/
}
#line 2780 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 73: /* selectnowith ::= selectnowith multiselect_op oneselect */
#line 519 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  Select *pRhs = yymsp[0].minor.yy99;
  Select *pLhs = yymsp[-2].minor.yy99;
  if( pRhs && pRhs->pPrior ){
    SrcList *pFrom;
    Token x;
    x.n = 0;
    parserDoubleLinkSelect(pParse, pRhs);
    pFrom = sqlSrcListAppendFromTerm(pParse,0,0,&x,pRhs,0,0);
    pRhs = sqlSelectNew(pParse,0,pFrom,0,0,0,0,0,0,0);
  }
  if( pRhs ){
    pRhs->op = (u8)yymsp[-1].minor.yy112;
    pRhs->pPrior = pLhs;
    if( ALWAYS(pLhs) ) pLhs->selFlags &= ~SF_MultiValue;
    pRhs->selFlags &= ~SF_MultiValue;
    if( yymsp[-1].minor.yy112!=TK_ALL ) pParse->hasCompound = 1;
  }else{
    sql_select_delete(pParse->db, pLhs);
  }
  yymsp[-2].minor.yy99 = pRhs;
}
#line 2806 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 74: /* multiselect_op ::= UNION */
      case 76: /* multiselect_op ::= EXCEPT|INTERSECT */ yytestcase(yyruleno==76);
#line 542 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = yymsp[0].major; /*A-overwrites-OP*/}
#line 2812 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 75: /* multiselect_op ::= UNION ALL */
#line 543 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-1].minor.yy112 = TK_ALL;}
#line 2817 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 77: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 547 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
#ifdef SQL_DEBUG
  Token s = yymsp[-8].minor.yy0; /*A-overwrites-S*/
#endif
  if (yymsp[0].minor.yy4.pLimit != NULL)
    sql_expr_check_sort_orders(pParse, yymsp[-1].minor.yy142);
  yymsp[-8].minor.yy99 = sqlSelectNew(pParse,yymsp[-6].minor.yy142,yymsp[-5].minor.yy367,yymsp[-4].minor.yy422,yymsp[-3].minor.yy142,yymsp[-2].minor.yy422,yymsp[-1].minor.yy142,yymsp[-7].minor.yy112,yymsp[0].minor.yy4.pLimit,yymsp[0].minor.yy4.pOffset);
#ifdef SQL_DEBUG
  /* Populate the Select.zSelName[] string that is used to help with
  ** query planner debugging, to differentiate between multiple Select
  ** objects in a complex query.
  **
  ** If the SELECT keyword is immediately followed by a C-style comment
  ** then extract the first few alphanumeric characters from within that
  ** comment to be the zSelName value.  Otherwise, the label is #N where
  ** is an integer that is incremented with each SELECT statement seen.
  */
  if( yymsp[-8].minor.yy99!=0 ){
    const char *z = s.z+6;
    int i;
    sql_snprintf(sizeof(yymsp[-8].minor.yy99->zSelName), yymsp[-8].minor.yy99->zSelName, "#%d",
                     ++pParse->nSelect);
    while( z[0]==' ' ) z++;
    if( z[0]=='/' && z[1]=='*' ){
      z += 2;
      while( z[0]==' ' ) z++;
      for(i=0; sqlIsalnum(z[i]); i++){}
      sql_snprintf(sizeof(yymsp[-8].minor.yy99->zSelName), yymsp[-8].minor.yy99->zSelName, "%.*s", i, z);
    }
  }
#endif /* SQL_DEBUG */
}
#line 2853 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 78: /* values ::= VALUES LP nexprlist RP */
#line 583 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy99 = sqlSelectNew(pParse,yymsp[-1].minor.yy142,0,0,0,0,0,SF_Values,0,0);
}
#line 2860 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 79: /* values ::= values COMMA LP exprlist RP */
#line 586 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  Select *pRight, *pLeft = yymsp[-4].minor.yy99;
  pRight = sqlSelectNew(pParse,yymsp[-1].minor.yy142,0,0,0,0,0,SF_Values|SF_MultiValue,0,0);
  if( ALWAYS(pLeft) ) pLeft->selFlags &= ~SF_MultiValue;
  if( pRight ){
    pRight->op = TK_ALL;
    pRight->pPrior = pLeft;
    yymsp[-4].minor.yy99 = pRight;
  }else{
    yymsp[-4].minor.yy99 = pLeft;
  }
}
#line 2876 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 80: /* distinct ::= DISTINCT */
#line 603 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = SF_Distinct;}
#line 2881 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 81: /* distinct ::= ALL */
#line 604 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = SF_All;}
#line 2886 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 83: /* sclp ::= */
      case 109: /* orderby_opt ::= */ yytestcase(yyruleno==109);
      case 120: /* groupby_opt ::= */ yytestcase(yyruleno==120);
      case 206: /* exprlist ::= */ yytestcase(yyruleno==206);
      case 209: /* paren_exprlist ::= */ yytestcase(yyruleno==209);
      case 214: /* eidlist_opt ::= */ yytestcase(yyruleno==214);
#line 617 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy142 = 0;}
#line 2896 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 84: /* selcollist ::= sclp expr as */
#line 618 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
   yymsp[-2].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-2].minor.yy142, yymsp[-1].minor.yy82.pExpr);
   if( yymsp[0].minor.yy0.n>0 ) sqlExprListSetName(pParse, yymsp[-2].minor.yy142, &yymsp[0].minor.yy0, 1);
   sqlExprListSetSpan(pParse,yymsp[-2].minor.yy142,&yymsp[-1].minor.yy82);
}
#line 2905 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 85: /* selcollist ::= sclp STAR */
#line 623 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_anon(pParse->db, TK_ASTERISK);
  if (p == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-1].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy142, p);
}
#line 2917 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 86: /* selcollist ::= sclp nm DOT STAR */
#line 631 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  struct Expr *pLeft = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (pLeft == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Expr *pRight = sqlPExpr(pParse, TK_ASTERISK, 0, 0);
  Expr *pDot = sqlPExpr(pParse, TK_DOT, pLeft, pRight);
  yymsp[-3].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy142, pDot);
}
#line 2931 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 87: /* as ::= AS nm */
#line 646 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-1].minor.yy0 = yymsp[0].minor.yy0;}
#line 2936 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 88: /* as ::= */
#line 648 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy0.n = 0; yymsp[1].minor.yy0.z = 0;}
#line 2941 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 89: /* from ::= */
#line 660 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy367 = sqlDbMallocZero(pParse->db, sizeof(*yymsp[1].minor.yy367));}
#line 2946 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 90: /* from ::= FROM seltablist */
#line 661 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy367 = yymsp[0].minor.yy367;
  sqlSrcListShiftJoinType(yymsp[-1].minor.yy367);
}
#line 2954 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 91: /* stl_prefix ::= seltablist joinop */
#line 669 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
   if( ALWAYS(yymsp[-1].minor.yy367 && yymsp[-1].minor.yy367->nSrc>0) ) yymsp[-1].minor.yy367->a[yymsp[-1].minor.yy367->nSrc-1].fg.jointype = (u8)yymsp[0].minor.yy112;
}
#line 2961 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 92: /* stl_prefix ::= */
#line 672 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy367 = 0;}
#line 2966 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 93: /* seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt */
#line 674 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-5].minor.yy367,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy422,yymsp[0].minor.yy420);
  sqlSrcListIndexedBy(pParse, yymsp[-5].minor.yy367, &yymsp[-2].minor.yy0);
}
#line 2974 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 94: /* seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt */
#line 679 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-7].minor.yy367,&yymsp[-6].minor.yy0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy422,yymsp[0].minor.yy420);
  sqlSrcListFuncArgs(pParse, yymsp[-7].minor.yy367, yymsp[-4].minor.yy142);
}
#line 2982 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 95: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 684 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy367,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy99,yymsp[-1].minor.yy422,yymsp[0].minor.yy420);
}
#line 2989 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 96: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 688 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  if( yymsp[-6].minor.yy367==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy422==0 && yymsp[0].minor.yy420==0 ){
    yymsp[-6].minor.yy367 = yymsp[-4].minor.yy367;
  }else if( yymsp[-4].minor.yy367->nSrc==1 ){
    yymsp[-6].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy367,0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy422,yymsp[0].minor.yy420);
    if( yymsp[-6].minor.yy367 ){
      struct SrcList_item *pNew = &yymsp[-6].minor.yy367->a[yymsp[-6].minor.yy367->nSrc-1];
      struct SrcList_item *pOld = yymsp[-4].minor.yy367->a;
      pNew->zName = pOld->zName;
      pNew->pSelect = pOld->pSelect;
      pOld->zName =  0;
      pOld->pSelect = 0;
    }
    sqlSrcListDelete(pParse->db, yymsp[-4].minor.yy367);
  }else{
    Select *pSubquery;
    sqlSrcListShiftJoinType(yymsp[-4].minor.yy367);
    pSubquery = sqlSelectNew(pParse,0,yymsp[-4].minor.yy367,0,0,0,0,SF_NestedFrom,0,0);
    yymsp[-6].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy367,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy422,yymsp[0].minor.yy420);
  }
}
#line 3014 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 97: /* fullname ::= nm */
#line 712 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  /* yylhsminor.yy367-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy367 = sql_src_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy367 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3026 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[0].minor.yy367 = yylhsminor.yy367;
        break;
      case 98: /* joinop ::= COMMA|JOIN */
#line 725 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = JT_INNER; }
#line 3032 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 99: /* joinop ::= JOIN_KW JOIN */
#line 727 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-1].minor.yy112 = sqlJoinType(pParse,&yymsp[-1].minor.yy0,0,0);  /*X-overwrites-A*/}
#line 3037 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 100: /* joinop ::= JOIN_KW join_nm JOIN */
#line 729 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-2].minor.yy112 = sqlJoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); /*X-overwrites-A*/}
#line 3042 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 101: /* joinop ::= JOIN_KW join_nm join_nm JOIN */
#line 731 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-3].minor.yy112 = sqlJoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0);/*X-overwrites-A*/}
#line 3047 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 102: /* on_opt ::= ON expr */
      case 123: /* having_opt ::= HAVING expr */ yytestcase(yyruleno==123);
      case 131: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==131);
      case 204: /* case_else ::= ELSE expr */ yytestcase(yyruleno==204);
#line 735 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-1].minor.yy422 = yymsp[0].minor.yy82.pExpr;}
#line 3055 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 103: /* on_opt ::= */
      case 122: /* having_opt ::= */ yytestcase(yyruleno==122);
      case 130: /* where_opt ::= */ yytestcase(yyruleno==130);
      case 205: /* case_else ::= */ yytestcase(yyruleno==205);
#line 736 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy422 = 0;}
#line 3063 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 104: /* indexed_opt ::= */
#line 749 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy0.z=0; yymsp[1].minor.yy0.n=0;}
#line 3068 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 105: /* indexed_opt ::= INDEXED BY nm */
#line 750 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;}
#line 3073 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 106: /* indexed_opt ::= NOT INDEXED */
#line 751 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-1].minor.yy0.z=0; yymsp[-1].minor.yy0.n=1;}
#line 3078 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 107: /* using_opt ::= USING LP idlist RP */
#line 755 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-3].minor.yy420 = yymsp[-1].minor.yy420;}
#line 3083 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 108: /* using_opt ::= */
      case 141: /* idlist_opt ::= */ yytestcase(yyruleno==141);
#line 756 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy420 = 0;}
#line 3089 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 110: /* orderby_opt ::= ORDER BY sortlist */
      case 121: /* groupby_opt ::= GROUP BY nexprlist */ yytestcase(yyruleno==121);
#line 770 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-2].minor.yy142 = yymsp[0].minor.yy142;}
#line 3095 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 111: /* sortlist ::= sortlist COMMA expr sortorder */
#line 771 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy142,yymsp[-1].minor.yy82.pExpr);
  sqlExprListSetSortOrder(yymsp[-3].minor.yy142,yymsp[0].minor.yy112);
}
#line 3103 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 112: /* sortlist ::= expr sortorder */
#line 775 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  /* yylhsminor.yy142-overwrites-yymsp[-1].minor.yy82. */
  yylhsminor.yy142 = sql_expr_list_append(pParse->db,NULL,yymsp[-1].minor.yy82.pExpr);
  sqlExprListSetSortOrder(yylhsminor.yy142,yymsp[0].minor.yy112);
}
#line 3112 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-1].minor.yy142 = yylhsminor.yy142;
        break;
      case 113: /* col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc */
#line 789 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  uint32_t fieldno;
  if (yymsp[0].minor.yy112 == 1) {
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy82.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  yymsp[-3].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy142, yymsp[-1].minor.yy82.pExpr);
}
#line 3127 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 114: /* col_list_with_autoinc ::= expr autoinc */
#line 800 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  if (yymsp[0].minor.yy112 == 1) {
    uint32_t fieldno = 0;
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy82.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  /* yylhsminor.yy142-overwrites-yymsp[-1].minor.yy82. */
  yylhsminor.yy142 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy82.pExpr);
}
#line 3142 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-1].minor.yy142 = yylhsminor.yy142;
        break;
      case 115: /* enable ::= ENABLE */
#line 813 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy497 = true;}
#line 3148 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 116: /* enable ::= DISABLE */
#line 814 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy497 = false;}
#line 3153 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 117: /* sortorder ::= ASC */
#line 818 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = SORT_ORDER_ASC;}
#line 3158 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 118: /* sortorder ::= DESC */
#line 819 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = SORT_ORDER_DESC;}
#line 3163 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 119: /* sortorder ::= */
#line 820 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy112 = SORT_ORDER_UNDEF;}
#line 3168 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 124: /* limit_opt ::= */
#line 845 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy4.pLimit = 0; yymsp[1].minor.yy4.pOffset = 0;}
#line 3173 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 125: /* limit_opt ::= LIMIT expr */
#line 846 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-1].minor.yy4.pLimit = yymsp[0].minor.yy82.pExpr; yymsp[-1].minor.yy4.pOffset = 0;}
#line 3178 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 126: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 848 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-3].minor.yy4.pLimit = yymsp[-2].minor.yy82.pExpr; yymsp[-3].minor.yy4.pOffset = yymsp[0].minor.yy82.pExpr;}
#line 3183 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 127: /* limit_opt ::= LIMIT expr COMMA expr */
#line 850 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-3].minor.yy4.pOffset = yymsp[-2].minor.yy82.pExpr; yymsp[-3].minor.yy4.pLimit = yymsp[0].minor.yy82.pExpr;}
#line 3188 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 128: /* cmd ::= with DELETE FROM fullname indexed_opt where_opt */
#line 854 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy91, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-2].minor.yy367, &yymsp[-1].minor.yy0);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sql_table_delete_from(pParse,yymsp[-2].minor.yy367,yymsp[0].minor.yy422);
}
#line 3200 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 129: /* cmd ::= TRUNCATE TABLE fullname */
#line 865 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  pParse->initiateTTrans = true;
  sql_table_truncate(pParse, yymsp[0].minor.yy367);
}
#line 3208 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 132: /* cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 879 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-7].minor.yy91, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-4].minor.yy367, &yymsp[-3].minor.yy0);
  if (yymsp[-1].minor.yy142 != NULL && yymsp[-1].minor.yy142->nExpr > pParse->db->aLimit[SQL_LIMIT_COLUMN]) {
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of columns in set "\
             "list", yymsp[-1].minor.yy142->nExpr, pParse->db->aLimit[SQL_LIMIT_COLUMN]);
    pParse->is_aborted = true;
  }
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlUpdate(pParse,yymsp[-4].minor.yy367,yymsp[-1].minor.yy142,yymsp[0].minor.yy422,yymsp[-5].minor.yy112);
}
#line 3225 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 133: /* setlist ::= setlist COMMA nm EQ expr */
#line 896 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy142, yymsp[0].minor.yy82.pExpr);
  sqlExprListSetName(pParse, yymsp[-4].minor.yy142, &yymsp[-2].minor.yy0, 1);
}
#line 3233 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 134: /* setlist ::= setlist COMMA LP idlist RP EQ expr */
#line 900 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy142 = sqlExprListAppendVector(pParse, yymsp[-6].minor.yy142, yymsp[-3].minor.yy420, yymsp[0].minor.yy82.pExpr);
}
#line 3240 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 135: /* setlist ::= nm EQ expr */
#line 903 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yylhsminor.yy142 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy82.pExpr);
  sqlExprListSetName(pParse, yylhsminor.yy142, &yymsp[-2].minor.yy0, 1);
}
#line 3248 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-2].minor.yy142 = yylhsminor.yy142;
        break;
      case 136: /* setlist ::= LP idlist RP EQ expr */
#line 907 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy142 = sqlExprListAppendVector(pParse, 0, yymsp[-3].minor.yy420, yymsp[0].minor.yy82.pExpr);
}
#line 3256 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 137: /* cmd ::= with insert_cmd INTO fullname idlist_opt select */
#line 913 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy91, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-2].minor.yy367, yymsp[0].minor.yy99, yymsp[-1].minor.yy420, yymsp[-4].minor.yy112);
}
#line 3267 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 138: /* cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES */
#line 921 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-6].minor.yy91, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-3].minor.yy367, 0, yymsp[-2].minor.yy420, yymsp[-5].minor.yy112);
}
#line 3278 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 142: /* idlist_opt ::= LP idlist RP */
#line 939 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-2].minor.yy420 = yymsp[-1].minor.yy420;}
#line 3283 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 143: /* idlist ::= idlist COMMA nm */
#line 940 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy420 = sql_id_list_append(pParse->db,yymsp[-2].minor.yy420,&yymsp[0].minor.yy0);
  if (yymsp[-2].minor.yy420 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3294 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 144: /* idlist ::= nm */
#line 947 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  /* yylhsminor.yy420-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy420 = sql_id_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy420 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3306 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[0].minor.yy420 = yylhsminor.yy420;
        break;
      case 145: /* expr ::= LP expr RP */
#line 1050 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{spanSet(&yymsp[-2].minor.yy82,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/  yymsp[-2].minor.yy82.pExpr = yymsp[-1].minor.yy82.pExpr;}
#line 3312 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 146: /* term ::= NULL */
      case 150: /* term ::= FLOAT|BLOB */ yytestcase(yyruleno==150);
      case 151: /* term ::= STRING */ yytestcase(yyruleno==151);
      case 152: /* term ::= FALSE */ yytestcase(yyruleno==152);
      case 153: /* term ::= TRUE */ yytestcase(yyruleno==153);
      case 154: /* term ::= UNKNOWN */ yytestcase(yyruleno==154);
#line 1051 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy82,pParse,yymsp[0].major,yymsp[0].minor.yy0);/*A-overwrites-X*/}
#line 3322 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 147: /* expr ::= ID|INDEXED */
      case 148: /* expr ::= JOIN_KW */ yytestcase(yyruleno==148);
#line 1052 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy82,pParse,TK_ID,yymsp[0].minor.yy0); /*A-overwrites-X*/}
#line 3328 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 149: /* expr ::= nm DOT nm */
#line 1054 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  struct Expr *temp1 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (temp1 == NULL) {
    pParse->is_aborted = true;
    return;
  }
  struct Expr *temp2 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[0].minor.yy0);
  if (temp2 == NULL) {
    sql_expr_delete(pParse->db, temp1, false);
    pParse->is_aborted = true;
    return;
  }
  spanSet(&yymsp[-2].minor.yy82,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-2].minor.yy82.pExpr = sqlPExpr(pParse, TK_DOT, temp1, temp2);
}
#line 3347 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 155: /* term ::= INTEGER */
#line 1075 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yylhsminor.yy82.pExpr = sql_expr_new_dequoted(pParse->db, TK_INTEGER, &yymsp[0].minor.yy0);
  if (yylhsminor.yy82.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yylhsminor.yy82.pExpr->type = FIELD_TYPE_INTEGER;
  yylhsminor.yy82.zStart = yymsp[0].minor.yy0.z;
  yylhsminor.yy82.zEnd = yymsp[0].minor.yy0.z + yymsp[0].minor.yy0.n;
  if( yylhsminor.yy82.pExpr ) yylhsminor.yy82.pExpr->flags |= EP_Leaf;
}
#line 3362 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[0].minor.yy82 = yylhsminor.yy82;
        break;
      case 156: /* expr ::= VARIABLE */
#line 1086 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  Token t = yymsp[0].minor.yy0;
  if (pParse->parse_only) {
    spanSet(&yylhsminor.yy82, &t, &t);
    diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
             pParse->line_pos, "bindings are not allowed in DDL");
    pParse->is_aborted = true;
    yylhsminor.yy82.pExpr = NULL;
  } else if (!(yymsp[0].minor.yy0.z[0]=='#' && sqlIsdigit(yymsp[0].minor.yy0.z[1]))) {
    u32 n = yymsp[0].minor.yy0.n;
    spanExpr(&yylhsminor.yy82, pParse, TK_VARIABLE, yymsp[0].minor.yy0);
    if (yylhsminor.yy82.pExpr->u.zToken[0] == '?' && n > 1) {
      diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
      pParse->is_aborted = true;
    } else {
      sqlExprAssignVarNumber(pParse, yylhsminor.yy82.pExpr, n);
    }
  }else{
    assert( t.n>=2 );
    spanSet(&yylhsminor.yy82, &t, &t);
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
    pParse->is_aborted = true;
    yylhsminor.yy82.pExpr = NULL;
  }
}
#line 3392 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[0].minor.yy82 = yylhsminor.yy82;
        break;
      case 157: /* expr ::= expr COLLATE ID|INDEXED */
#line 1111 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy82.pExpr = sqlExprAddCollateToken(pParse, yymsp[-2].minor.yy82.pExpr, &yymsp[0].minor.yy0, 1);
  yymsp[-2].minor.yy82.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3401 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 158: /* expr ::= CAST LP expr AS typedef RP */
#line 1116 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy82,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-5].minor.yy82.pExpr = sql_expr_new_dequoted(pParse->db, TK_CAST, NULL);
  if (yymsp[-5].minor.yy82.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy82.pExpr->type = yymsp[-1].minor.yy330.type;
  sqlExprAttachSubtrees(pParse->db, yymsp[-5].minor.yy82.pExpr, yymsp[-3].minor.yy82.pExpr, 0);
}
#line 3415 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 159: /* expr ::= TRIM LP trim_operands RP */
#line 1127 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yylhsminor.yy82.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy3, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy82, &yymsp[-3].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3423 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-3].minor.yy82 = yylhsminor.yy82;
        break;
      case 160: /* trim_operands ::= trim_from_clause expr */
#line 1135 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy3, yymsp[0].minor.yy82.pExpr);
}
#line 3431 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-1].minor.yy3 = yylhsminor.yy3;
        break;
      case 161: /* trim_operands ::= expr */
#line 1139 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy82.pExpr);
}
#line 3439 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[0].minor.yy3 = yylhsminor.yy3;
        break;
      case 162: /* trim_from_clause ::= expr FROM */
#line 1151 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy82.pExpr);
}
#line 3447 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-1].minor.yy3 = yylhsminor.yy3;
        break;
      case 163: /* trim_from_clause ::= trim_specification expr_optional FROM */
#line 1155 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-2].minor.yy385]);
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, NULL, p);
  if (yymsp[-1].minor.yy299 != NULL)
    yylhsminor.yy3 = sql_expr_list_append(pParse->db, yylhsminor.yy3, yymsp[-1].minor.yy299);
}
#line 3459 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-2].minor.yy3 = yylhsminor.yy3;
        break;
      case 164: /* expr_optional ::= */
#line 1166 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[1].minor.yy299 = NULL; }
#line 3465 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 165: /* expr_optional ::= expr */
#line 1167 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yylhsminor.yy299 = yymsp[0].minor.yy82.pExpr; }
#line 3470 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[0].minor.yy299 = yylhsminor.yy299;
        break;
      case 166: /* trim_specification ::= LEADING */
#line 1171 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy385 = TRIM_LEADING; }
#line 3476 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 167: /* trim_specification ::= TRAILING */
#line 1172 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy385 = TRIM_TRAILING; }
#line 3481 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 168: /* trim_specification ::= BOTH */
#line 1173 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy385 = TRIM_BOTH; }
#line 3486 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 169: /* expr ::= ID|INDEXED LP distinct exprlist RP */
      case 170: /* expr ::= type_func LP distinct exprlist RP */ yytestcase(yyruleno==170);
#line 1175 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy142 && yymsp[-1].minor.yy142->nExpr>pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG] ){
    const char *err =
      tt_sprintf("Number of arguments to function %.*s", yymsp[-4].minor.yy0.n, yymsp[-4].minor.yy0.z);
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, err, yymsp[-1].minor.yy142->nExpr,
             pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG]);
    pParse->is_aborted = true;
  }
  yylhsminor.yy82.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy142, &yymsp[-4].minor.yy0);
  spanSet(&yylhsminor.yy82,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy112==SF_Distinct && yylhsminor.yy82.pExpr ){
    yylhsminor.yy82.pExpr->flags |= EP_Distinct;
  }
}
#line 3505 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-4].minor.yy82 = yylhsminor.yy82;
        break;
      case 171: /* expr ::= ID|INDEXED LP STAR RP */
#line 1210 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yylhsminor.yy82.pExpr = sqlExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy82,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 3514 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-3].minor.yy82 = yylhsminor.yy82;
        break;
      case 172: /* expr ::= LP nexprlist COMMA expr RP */
#line 1245 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy142, yymsp[-1].minor.yy82.pExpr);
  yylhsminor.yy82.pExpr = sqlPExpr(pParse, TK_VECTOR, 0, 0);
  if( yylhsminor.yy82.pExpr ){
    yylhsminor.yy82.pExpr->x.pList = pList;
    spanSet(&yylhsminor.yy82, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
  }else{
    sql_expr_list_delete(pParse->db, pList);
  }
}
#line 3529 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-4].minor.yy82 = yylhsminor.yy82;
        break;
      case 173: /* expr ::= expr AND expr */
      case 174: /* expr ::= expr OR expr */ yytestcase(yyruleno==174);
      case 175: /* expr ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==175);
      case 176: /* expr ::= expr EQ|NE expr */ yytestcase(yyruleno==176);
      case 177: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==177);
      case 178: /* expr ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==178);
      case 179: /* expr ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==179);
      case 180: /* expr ::= expr CONCAT expr */ yytestcase(yyruleno==180);
#line 1256 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{spanBinaryExpr(pParse,yymsp[-1].major,&yymsp[-2].minor.yy82,&yymsp[0].minor.yy82);}
#line 3542 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 181: /* likeop ::= LIKE_KW|MATCH */
#line 1269 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy0=yymsp[0].minor.yy0;/*A-overwrites-X*/}
#line 3547 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 182: /* likeop ::= NOT LIKE_KW|MATCH */
#line 1270 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-1].minor.yy0=yymsp[0].minor.yy0; yymsp[-1].minor.yy0.n|=0x80000000; /*yymsp[-1].minor.yy0-overwrite-yymsp[0].minor.yy0*/}
#line 3552 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 183: /* expr ::= expr likeop expr */
#line 1271 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-1].minor.yy0.n & 0x80000000;
  yymsp[-1].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[0].minor.yy82.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-2].minor.yy82.pExpr);
  yymsp[-2].minor.yy82.pExpr = sqlExprFunction(pParse, pList, &yymsp[-1].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-2].minor.yy82);
  yymsp[-2].minor.yy82.zEnd = yymsp[0].minor.yy82.zEnd;
  if( yymsp[-2].minor.yy82.pExpr ) yymsp[-2].minor.yy82.pExpr->flags |= EP_InfixFunc;
}
#line 3567 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 184: /* expr ::= expr likeop expr ESCAPE expr */
#line 1282 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-3].minor.yy0.n & 0x80000000;
  yymsp[-3].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy82.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-4].minor.yy82.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy82.pExpr);
  yymsp[-4].minor.yy82.pExpr = sqlExprFunction(pParse, pList, &yymsp[-3].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-4].minor.yy82);
  yymsp[-4].minor.yy82.zEnd = yymsp[0].minor.yy82.zEnd;
  if( yymsp[-4].minor.yy82.pExpr ) yymsp[-4].minor.yy82.pExpr->flags |= EP_InfixFunc;
}
#line 3583 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 185: /* expr ::= expr IS NULL */
#line 1312 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_ISNULL,&yymsp[-2].minor.yy82,&yymsp[0].minor.yy0);}
#line 3588 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 186: /* expr ::= expr IS NOT NULL */
#line 1313 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_NOTNULL,&yymsp[-3].minor.yy82,&yymsp[0].minor.yy0);}
#line 3593 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 187: /* expr ::= NOT expr */
      case 188: /* expr ::= BITNOT expr */ yytestcase(yyruleno==188);
#line 1335 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy82,pParse,yymsp[-1].major,&yymsp[0].minor.yy82,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3599 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 189: /* expr ::= MINUS expr */
#line 1339 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy82,pParse,TK_UMINUS,&yymsp[0].minor.yy82,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3604 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 190: /* expr ::= PLUS expr */
#line 1341 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy82,pParse,TK_UPLUS,&yymsp[0].minor.yy82,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3609 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 191: /* between_op ::= BETWEEN */
      case 194: /* in_op ::= IN */ yytestcase(yyruleno==194);
#line 1344 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = 0;}
#line 3615 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 193: /* expr ::= expr between_op expr AND expr */
#line 1346 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy82.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy82.pExpr);
  yymsp[-4].minor.yy82.pExpr = sqlPExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy82.pExpr, 0);
  if( yymsp[-4].minor.yy82.pExpr ){
    yymsp[-4].minor.yy82.pExpr->x.pList = pList;
  }else{
    sql_expr_list_delete(pParse->db, pList);
  } 
  exprNot(pParse, yymsp[-3].minor.yy112, &yymsp[-4].minor.yy82);
  yymsp[-4].minor.yy82.zEnd = yymsp[0].minor.yy82.zEnd;
}
#line 3631 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 196: /* expr ::= expr in_op LP exprlist RP */
#line 1361 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy142==0 ){
    /* Expressions of the form
    **
    **      expr1 IN ()
    **      expr1 NOT IN ()
    **
    ** simplify to constants 0 (false) and 1 (true), respectively,
    ** regardless of the value of expr1.
    */
    sql_expr_delete(pParse->db, yymsp[-4].minor.yy82.pExpr, false);
    int tk = yymsp[-3].minor.yy112 == 0 ? TK_FALSE : TK_TRUE;
    yymsp[-4].minor.yy82.pExpr = sql_expr_new_anon(pParse->db, tk);
    if (yymsp[-4].minor.yy82.pExpr == NULL) {
      pParse->is_aborted = true;
      return;
    }
    yymsp[-4].minor.yy82.pExpr->type = FIELD_TYPE_BOOLEAN;
  }else if( yymsp[-1].minor.yy142->nExpr==1 ){
    /* Expressions of the form:
    **
    **      expr1 IN (?1)
    **      expr1 NOT IN (?2)
    **
    ** with exactly one value on the RHS can be simplified to something
    ** like this:
    **
    **      expr1 == ?1
    **      expr1 <> ?2
    */
    Expr *pRHS = yymsp[-1].minor.yy142->a[0].pExpr;
    yymsp[-1].minor.yy142->a[0].pExpr = 0;
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy142);
    yymsp[-4].minor.yy82.pExpr = sqlPExpr(pParse, yymsp[-3].minor.yy112 ? TK_NE : TK_EQ, yymsp[-4].minor.yy82.pExpr, pRHS);
  }else{
    yymsp[-4].minor.yy82.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy82.pExpr, 0);
    if( yymsp[-4].minor.yy82.pExpr ){
      yymsp[-4].minor.yy82.pExpr->x.pList = yymsp[-1].minor.yy142;
      sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy82.pExpr);
    }else{
      sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy142);
    }
    exprNot(pParse, yymsp[-3].minor.yy112, &yymsp[-4].minor.yy82);
  }
  yymsp[-4].minor.yy82.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3681 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 197: /* expr ::= LP select RP */
#line 1407 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  spanSet(&yymsp[-2].minor.yy82,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  yymsp[-2].minor.yy82.pExpr = sqlPExpr(pParse, TK_SELECT, 0, 0);
  sqlPExprAddSelect(pParse, yymsp[-2].minor.yy82.pExpr, yymsp[-1].minor.yy99);
}
#line 3690 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 198: /* expr ::= expr in_op LP select RP */
#line 1412 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy82.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy82.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-4].minor.yy82.pExpr, yymsp[-1].minor.yy99);
  exprNot(pParse, yymsp[-3].minor.yy112, &yymsp[-4].minor.yy82);
  yymsp[-4].minor.yy82.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3700 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 199: /* expr ::= expr in_op nm paren_exprlist */
#line 1418 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  struct SrcList *pSrc = sql_src_list_append(pParse->db, 0,&yymsp[-1].minor.yy0);
  if (pSrc == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Select *pSelect = sqlSelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
  if( yymsp[0].minor.yy142 )  sqlSrcListFuncArgs(pParse, pSelect ? pSrc : 0, yymsp[0].minor.yy142);
  yymsp[-3].minor.yy82.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-3].minor.yy82.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-3].minor.yy82.pExpr, pSelect);
  exprNot(pParse, yymsp[-2].minor.yy112, &yymsp[-3].minor.yy82);
  yymsp[-3].minor.yy82.zEnd = &yymsp[-1].minor.yy0.z[yymsp[-1].minor.yy0.n];
}
#line 3717 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 200: /* expr ::= EXISTS LP select RP */
#line 1431 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  Expr *p;
  spanSet(&yymsp[-3].minor.yy82,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  p = yymsp[-3].minor.yy82.pExpr = sqlPExpr(pParse, TK_EXISTS, 0, 0);
  sqlPExprAddSelect(pParse, p, yymsp[-1].minor.yy99);
}
#line 3727 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 201: /* expr ::= CASE expr_optional case_exprlist case_else END */
#line 1439 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  spanSet(&yymsp[-4].minor.yy82,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-C*/
  yymsp[-4].minor.yy82.pExpr = sqlPExpr(pParse, TK_CASE, yymsp[-3].minor.yy299, 0);
  if( yymsp[-4].minor.yy82.pExpr ){
    yymsp[-4].minor.yy82.pExpr->x.pList = yymsp[-1].minor.yy422 ? sql_expr_list_append(pParse->db,yymsp[-2].minor.yy142,yymsp[-1].minor.yy422) : yymsp[-2].minor.yy142;
    sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy82.pExpr);
  }else{
    sql_expr_list_delete(pParse->db, yymsp[-2].minor.yy142);
    sql_expr_delete(pParse->db, yymsp[-1].minor.yy422, false);
  }
}
#line 3742 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 202: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 1452 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy142, yymsp[-2].minor.yy82.pExpr);
  yymsp[-4].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy142, yymsp[0].minor.yy82.pExpr);
}
#line 3750 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 203: /* case_exprlist ::= WHEN expr THEN expr */
#line 1456 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy142 = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy82.pExpr);
  yymsp[-3].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy142, yymsp[0].minor.yy82.pExpr);
}
#line 3758 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 207: /* nexprlist ::= nexprlist COMMA expr */
#line 1473 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-2].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-2].minor.yy142,yymsp[0].minor.yy82.pExpr);}
#line 3763 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 208: /* nexprlist ::= expr */
#line 1475 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy142 = sql_expr_list_append(pParse->db,NULL,yymsp[0].minor.yy82.pExpr); /*A-overwrites-Y*/}
#line 3768 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 210: /* paren_exprlist ::= LP exprlist RP */
      case 215: /* eidlist_opt ::= LP eidlist RP */ yytestcase(yyruleno==215);
#line 1482 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-2].minor.yy142 = yymsp[-1].minor.yy142;}
#line 3774 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 211: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP */
#line 1488 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  struct SrcList *src_list = sql_src_list_append(pParse->db,0,&yymsp[-3].minor.yy0);
  if (src_list == NULL) {
    pParse->is_aborted = true;
    return;
  }
  create_index_def_init(&pParse->create_index_def, src_list, &yymsp[-5].minor.yy0, yymsp[-1].minor.yy142, yymsp[-8].minor.yy112,
                        SORT_ORDER_ASC, yymsp[-6].minor.yy112);
  pParse->initiateTTrans = true;
  sql_create_index(pParse);
}
#line 3789 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 212: /* uniqueflag ::= UNIQUE */
#line 1501 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = SQL_INDEX_TYPE_UNIQUE;}
#line 3794 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 213: /* uniqueflag ::= */
#line 1502 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy112 = SQL_INDEX_TYPE_NON_UNIQUE;}
#line 3799 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 216: /* eidlist ::= eidlist COMMA nm */
#line 1537 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy142 = parserAddExprIdListTerm(pParse, yymsp[-2].minor.yy142, &yymsp[0].minor.yy0);
}
#line 3806 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 217: /* eidlist ::= nm */
#line 1540 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[0].minor.yy142 = parserAddExprIdListTerm(pParse, 0, &yymsp[0].minor.yy0); /*A-overwrites-Y*/
}
#line 3813 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 218: /* cmd ::= DROP INDEX ifexists nm ON fullname */
#line 1547 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  drop_index_def_init(&pParse->drop_index_def, yymsp[0].minor.yy367, &yymsp[-2].minor.yy0, yymsp[-3].minor.yy112);
  pParse->initiateTTrans = true;
  sql_drop_index(pParse);
}
#line 3822 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 219: /* cmd ::= SET SESSION nm EQ term */
#line 1555 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
    sql_setting_set(pParse,&yymsp[-2].minor.yy0,yymsp[0].minor.yy82.pExpr);
}
#line 3829 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 220: /* cmd ::= PRAGMA nm */
#line 1561 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[0].minor.yy0,0,0);
}
#line 3836 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 221: /* cmd ::= PRAGMA nm LP nm RP */
#line 1564 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0);
}
#line 3843 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 222: /* cmd ::= PRAGMA nm LP nm DOT nm RP */
#line 1567 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-5].minor.yy0,&yymsp[-1].minor.yy0,&yymsp[-3].minor.yy0);
}
#line 3850 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 223: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1572 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  pParse->initiateTTrans = true;
  sql_trigger_finish(pParse, yymsp[-1].minor.yy527, &all);
}
#line 3861 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 224: /* trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1582 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_trigger_def_init(&pParse->create_trigger_def, yymsp[-2].minor.yy367, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy112, yymsp[-4].minor.yy450.a, yymsp[-4].minor.yy450.b, yymsp[0].minor.yy422,
                          yymsp[-7].minor.yy112);
  sql_trigger_begin(pParse);
  yymsp[-8].minor.yy0 = yymsp[-6].minor.yy0; /*yymsp[-8].minor.yy0-overwrites-T*/
}
#line 3871 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 225: /* trigger_time ::= BEFORE */
#line 1590 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = TK_BEFORE; }
#line 3876 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 226: /* trigger_time ::= AFTER */
#line 1591 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = TK_AFTER;  }
#line 3881 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 227: /* trigger_time ::= INSTEAD OF */
#line 1592 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = TK_INSTEAD;}
#line 3886 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 228: /* trigger_time ::= */
#line 1593 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[1].minor.yy112 = TK_BEFORE; }
#line 3891 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 229: /* trigger_event ::= DELETE|INSERT */
      case 230: /* trigger_event ::= UPDATE */ yytestcase(yyruleno==230);
#line 1597 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy450.a = yymsp[0].major; /*A-overwrites-X*/ yymsp[0].minor.yy450.b = 0;}
#line 3897 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 231: /* trigger_event ::= UPDATE OF idlist */
#line 1599 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[-2].minor.yy450.a = TK_UPDATE; yymsp[-2].minor.yy450.b = yymsp[0].minor.yy420;}
#line 3902 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 232: /* foreach_clause ::= */
#line 1601 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "FOR EACH STATEMENT triggers are not implemented, "
           "please supply FOR EACH ROW clause");
  pParse->is_aborted = true;
}
#line 3912 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 233: /* when_clause ::= */
#line 1611 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[1].minor.yy422 = 0; }
#line 3917 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 234: /* when_clause ::= WHEN expr */
#line 1612 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy422 = yymsp[0].minor.yy82.pExpr; }
#line 3922 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 235: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1616 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  assert( yymsp[-2].minor.yy527!=0 );
  yymsp[-2].minor.yy527->pLast->pNext = yymsp[-1].minor.yy527;
  yymsp[-2].minor.yy527->pLast = yymsp[-1].minor.yy527;
}
#line 3931 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 236: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1621 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ 
  assert( yymsp[-1].minor.yy527!=0 );
  yymsp[-1].minor.yy527->pLast = yymsp[-1].minor.yy527;
}
#line 3939 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 237: /* trnm ::= nm DOT nm */
#line 1632 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "qualified table names are not allowed on INSERT, "
           "UPDATE, and DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3950 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 238: /* tridxby ::= INDEXED BY nm */
#line 1645 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the INDEXED BY clause is not allowed on UPDATE "\
           "or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3960 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 239: /* tridxby ::= NOT INDEXED */
#line 1651 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the NOT INDEXED BY clause is not allowed on "\
           "UPDATE or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3970 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 240: /* trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt */
#line 1664 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
     yymsp[-6].minor.yy527 = sql_trigger_update_step(pParse->db, &yymsp[-4].minor.yy0, yymsp[-1].minor.yy142, yymsp[0].minor.yy422, yymsp[-5].minor.yy112);
     if (yymsp[-6].minor.yy527 == NULL) {
        pParse->is_aborted = true;
        return;
     }
   }
#line 3981 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 241: /* trigger_cmd ::= insert_cmd INTO trnm idlist_opt select */
#line 1673 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  /*yylhsminor.yy527-overwrites-yymsp[-4].minor.yy112. */
  yylhsminor.yy527 = sql_trigger_insert_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy420, yymsp[0].minor.yy99, yymsp[-4].minor.yy112);
  if (yylhsminor.yy527 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3993 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-4].minor.yy527 = yylhsminor.yy527;
        break;
      case 242: /* trigger_cmd ::= DELETE FROM trnm tridxby where_opt */
#line 1683 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy527 = sql_trigger_delete_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[0].minor.yy422);
  if (yymsp[-4].minor.yy527 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4005 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 243: /* trigger_cmd ::= select */
#line 1692 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  /* yylhsminor.yy527-overwrites-yymsp[0].minor.yy99. */
  yylhsminor.yy527 = sql_trigger_select_step(pParse->db, yymsp[0].minor.yy99);
  if (yylhsminor.yy527 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4017 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[0].minor.yy527 = yylhsminor.yy527;
        break;
      case 244: /* expr ::= RAISE LP IGNORE RP */
#line 1702 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  spanSet(&yymsp[-3].minor.yy82,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-3].minor.yy82.pExpr = sqlPExpr(pParse, TK_RAISE, 0, 0);
  if( yymsp[-3].minor.yy82.pExpr ){
    yymsp[-3].minor.yy82.pExpr->on_conflict_action = ON_CONFLICT_ACTION_IGNORE;
  }
}
#line 4029 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 245: /* expr ::= RAISE LP raisetype COMMA STRING RP */
#line 1709 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy82,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-5].minor.yy82.pExpr = sql_expr_new_dequoted(pParse->db, TK_RAISE, &yymsp[-1].minor.yy0);
  if(yymsp[-5].minor.yy82.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy82.pExpr->on_conflict_action = (enum on_conflict_action) yymsp[-3].minor.yy112;
}
#line 4042 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 246: /* raisetype ::= ROLLBACK */
#line 1720 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = ON_CONFLICT_ACTION_ROLLBACK;}
#line 4047 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 247: /* raisetype ::= ABORT */
#line 1721 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = ON_CONFLICT_ACTION_ABORT;}
#line 4052 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 248: /* raisetype ::= FAIL */
#line 1722 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = ON_CONFLICT_ACTION_FAIL;}
#line 4057 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 249: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1726 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_trigger_def_init(&pParse->drop_trigger_def, yymsp[0].minor.yy367, &t, yymsp[-1].minor.yy112);
  pParse->initiateTTrans = true;
  sql_drop_trigger(pParse);
}
#line 4067 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 250: /* alter_table_start ::= ALTER TABLE fullname */
#line 1743 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-2].minor.yy308 = yymsp[0].minor.yy367; }
#line 4072 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 251: /* alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm */
#line 1746 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
   yylhsminor.yy530.table_name = yymsp[-3].minor.yy308;
   yylhsminor.yy530.name = yymsp[0].minor.yy0;
   pParse->initiateTTrans = true;
 }
#line 4081 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-3].minor.yy530 = yylhsminor.yy530;
        break;
      case 252: /* alter_add_column ::= alter_table_start ADD column_name */
#line 1753 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yylhsminor.yy530.table_name = yymsp[-2].minor.yy308;
  yylhsminor.yy530.name = yymsp[0].minor.yy0;
  pParse->initiateTTrans = true;
}
#line 4091 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[-2].minor.yy530 = yylhsminor.yy530;
        break;
      case 253: /* column_name ::= COLUMN nm */
#line 1759 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; }
#line 4097 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 254: /* column_name ::= nm */
#line 1760 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yylhsminor.yy0 = yymsp[0].minor.yy0; }
#line 4102 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 255: /* alter_column_def ::= alter_add_column typedef */
#line 1764 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, yymsp[-1].minor.yy530.table_name, &yymsp[-1].minor.yy530.name, &yymsp[0].minor.yy330);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  sql_create_column_start(pParse);
}
#line 4113 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 256: /* cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 1772 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, yymsp[-11].minor.yy530.table_name, &yymsp[-11].minor.yy530.name, yymsp[-7].minor.yy142, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy142,
                     yymsp[-2].minor.yy112, yymsp[-1].minor.yy112, yymsp[0].minor.yy112);
  sql_create_foreign_key(pParse);
}
#line 4122 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 257: /* cmd ::= alter_add_constraint CHECK LP expr RP */
#line 1778 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
    create_ck_def_init(&pParse->create_ck_def, yymsp[-4].minor.yy530.table_name, &yymsp[-4].minor.yy530.name, &yymsp[-1].minor.yy82);
    sql_create_check_contraint(pParse);
}
#line 4130 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 258: /* cmd ::= alter_add_constraint unique_spec LP sortlist RP */
#line 1783 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, yymsp[-4].minor.yy530.table_name, &yymsp[-4].minor.yy530.name, yymsp[-1].minor.yy142, yymsp[-3].minor.yy112,
                        SORT_ORDER_ASC, false);
  sql_create_index(pParse);
}
#line 4139 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 259: /* unique_spec ::= UNIQUE */
#line 1790 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = SQL_INDEX_TYPE_CONSTRAINT_UNIQUE; }
#line 4144 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 260: /* unique_spec ::= PRIMARY KEY */
#line 1791 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = SQL_INDEX_TYPE_CONSTRAINT_PK; }
#line 4149 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 261: /* cmd ::= alter_table_start RENAME TO nm */
#line 1793 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
    rename_entity_def_init(&pParse->rename_entity_def, yymsp[-3].minor.yy308, &yymsp[0].minor.yy0);
    pParse->initiateTTrans = true;
    sql_alter_table_rename(pParse);
}
#line 4158 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 262: /* cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm */
#line 1799 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  drop_constraint_def_init(&pParse->drop_constraint_def, yymsp[-3].minor.yy367, &yymsp[0].minor.yy0, false);
  pParse->initiateTTrans = true;
  sql_drop_constraint(pParse);
}
#line 4167 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 263: /* cmd ::= alter_table_start enable CHECK CONSTRAINT nm */
#line 1805 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
    enable_entity_def_init(&pParse->enable_entity_def, ENTITY_TYPE_CK, yymsp[-4].minor.yy308,
                           &yymsp[0].minor.yy0, yymsp[-3].minor.yy497);
    sql_alter_ck_constraint_enable(pParse);
}
#line 4176 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 264: /* with ::= */
#line 1817 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{yymsp[1].minor.yy91 = 0;}
#line 4181 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 265: /* with ::= WITH wqlist */
#line 1818 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-1].minor.yy91 = yymsp[0].minor.yy91; }
#line 4186 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 266: /* with ::= WITH RECURSIVE wqlist */
#line 1819 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[-2].minor.yy91 = yymsp[0].minor.yy91; }
#line 4191 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 267: /* wqlist ::= nm eidlist_opt AS LP select RP */
#line 1821 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy91 = sqlWithAdd(pParse, 0, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy142, yymsp[-1].minor.yy99); /*A-overwrites-X*/
}
#line 4198 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 268: /* wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP */
#line 1824 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy91 = sqlWithAdd(pParse, yymsp[-7].minor.yy91, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy142, yymsp[-1].minor.yy99);
}
#line 4205 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 269: /* typedef ::= TEXT */
      case 270: /* typedef ::= STRING_KW */ yytestcase(yyruleno==270);
#line 1830 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_STRING; }
#line 4211 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 271: /* typedef ::= SCALAR */
#line 1832 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_SCALAR; }
#line 4216 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 272: /* typedef ::= BOOL */
      case 273: /* typedef ::= BOOLEAN */ yytestcase(yyruleno==273);
#line 1834 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_BOOLEAN; }
#line 4222 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 274: /* typedef ::= VARBINARY */
#line 1836 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_VARBINARY; }
#line 4227 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 275: /* typedef ::= UUID */
#line 1837 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_UUID; }
#line 4232 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 276: /* char_len ::= LP INTEGER RP */
#line 1849 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  (void) yymsp[-2].minor.yy112;
  (void) yymsp[-1].minor.yy0;
}
#line 4240 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 277: /* typedef ::= VARCHAR char_len */
#line 1855 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy330.type = FIELD_TYPE_STRING;
  (void) yymsp[0].minor.yy112;
}
#line 4248 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 278: /* number_typedef ::= NUMBER */
#line 1862 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_NUMBER; }
#line 4253 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 279: /* number_typedef ::= DOUBLE */
#line 1863 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_DOUBLE; }
#line 4258 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 280: /* number_typedef ::= INT|INTEGER_KW */
#line 1864 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_INTEGER; }
#line 4263 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      case 281: /* number_typedef ::= UNSIGNED */
#line 1865 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_UNSIGNED; }
#line 4268 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
        break;
      default:
      /* (282) input ::= ecmd */ yytestcase(yyruleno==282);
      /* (283) explain ::= */ yytestcase(yyruleno==283);
      /* (284) cmdx ::= cmd (OPTIMIZED OUT) */ assert(yyruleno!=284);
      /* (285) savepoint_opt ::= SAVEPOINT */ yytestcase(yyruleno==285);
      /* (286) savepoint_opt ::= */ yytestcase(yyruleno==286);
      /* (287) cmd ::= create_table create_table_args with_opts create_table_end */ yytestcase(yyruleno==287);
      /* (288) create_table_args ::= LP columnlist RP */ yytestcase(yyruleno==288);
      /* (289) with_opts ::= WITH engine_opts */ yytestcase(yyruleno==289);
      /* (290) with_opts ::= */ yytestcase(yyruleno==290);
      /* (291) columnlist ::= columnlist COMMA tcons */ yytestcase(yyruleno==291);
      /* (292) columnlist ::= columnlist COMMA column_def create_column_end */ yytestcase(yyruleno==292);
      /* (293) columnlist ::= column_def create_column_end */ yytestcase(yyruleno==293);
      /* (294) column_def ::= column_name_and_type carglist */ yytestcase(yyruleno==294);
      /* (295) columnlist ::= tcons (OPTIMIZED OUT) */ assert(yyruleno!=295);
      /* (296) carglist ::= carglist ccons */ yytestcase(yyruleno==296);
      /* (297) carglist ::= */ yytestcase(yyruleno==297);
      /* (298) ccons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=298);
      /* (299) tcons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=299);
      /* (300) defer_subclause_opt ::= defer_subclause (OPTIMIZED OUT) */ assert(yyruleno!=300);
      /* (301) resolvetype ::= raisetype (OPTIMIZED OUT) */ assert(yyruleno!=301);
      /* (302) selectnowith ::= oneselect (OPTIMIZED OUT) */ assert(yyruleno!=302);
      /* (303) oneselect ::= values */ yytestcase(yyruleno==303);
      /* (304) sclp ::= selcollist COMMA */ yytestcase(yyruleno==304);
      /* (305) as ::= ID|STRING */ yytestcase(yyruleno==305);
      /* (306) join_nm ::= ID|INDEXED */ yytestcase(yyruleno==306);
      /* (307) join_nm ::= JOIN_KW */ yytestcase(yyruleno==307);
      /* (308) expr ::= term (OPTIMIZED OUT) */ assert(yyruleno!=308);
      /* (309) type_func ::= CHAR */ yytestcase(yyruleno==309);
      /* (310) exprlist ::= nexprlist */ yytestcase(yyruleno==310);
      /* (311) foreach_clause ::= FOR EACH ROW */ yytestcase(yyruleno==311);
      /* (312) trnm ::= nm */ yytestcase(yyruleno==312);
      /* (313) tridxby ::= */ yytestcase(yyruleno==313);
      /* (314) cmd ::= alter_column_def carglist create_column_end */ yytestcase(yyruleno==314);
      /* (315) typedef ::= number_typedef (OPTIMIZED OUT) */ assert(yyruleno!=315);
        break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
/************ End %parse_failure code *****************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  sqlParserTOKENTYPE yyminor         /* The minor type of the error token */
){
  sqlParserARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 32 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  if (yypParser->is_fallback_failed && TOKEN.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, TOKEN.n, TOKEN.z, TOKEN.n, TOKEN.z);
  } else {
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, TOKEN.n,
             TOKEN.z);
  }
  pParse->is_aborted = true;
#line 4373 "/build/usr/src/debug/tarantool-2.9.0.192/src/box/sql/parse.c"
/************ End %syntax_error code ******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
  assert( yypParser->yytos==yypParser->yystack );
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
/*********** End %parse_accept code *******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlParserTOKENTYPE yyminor       /* The value for the token */
  sqlParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack
         PARSER_ERROR_CHECK);
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
  }
#endif
  return;
}
